// HyperRogue Turkish translation, by zulmetefza & Seyacim
// Copyright (C) 2011-2016 Zeno Rogue, see 'hyper.cpp' for details

// This translation file is encoded with UTF-8

// Nouns

#define Orb(X,Y) N("Orb of " X, GEN_F, Y " Küresi", Y " Küreleri", Y " Küresini", Y " Küresiyle")


// For each noun, provide the type of the noun, and all the grammatical forms
// required by HyperRogue. For example, in Polish each noun can be
// masculine living (GEN_M), masculine object (GEN_O),
// feminine (GEN_F), or neuter (GEN_N). The following forms are given:
// nominative (referred to as %1), nominative plural (%P1), accusative (%a1).
// Feel free to add more (or less) forms or types if needed.

// MONSTERS
// ========

N("Yeti", GEN_M, "Yeti", "Yeti", "Yeti", "Yeti")
N("Icewolf", GEN_M, "Buzkurdu", "Buzkurtları", "Buzkurdunu", "Buzkurduyla")
N("Ranger",  GEN_M, "Korucu", "Korucular", "Korucuyu","Korucuyla")
N("Rock Troll", GEN_M, "Kaya Trolü", "Kaya Trolleri", "Kaya Trolünü", "Kaya Trolüyle")
N("Goblin", GEN_M, "Goblin", "Goblinler", "Goblini", "Goblinle")
N("Sand Worm", GEN_M, "Kumkurdu", "Kumkurtları", "Kumkurdunu" , "Kumkurduyla")
N("Sand Worm Tail", GEN_M, "Kumkurdu Kuyruğu", "Kumkurdu Kuyrukları", "Kumkurdu Kuyruğunu" , "Kumkurdu Kuyruğuyla")
N("Sand Worm W", GEN_M, "Kumkurdu W", "Kumkurtları W", "Kumkurdunu W", "Kumkurduyla W")
N("Desert Man", GEN_M, "Bedevi", "Bedeviler", "Bedeviyi", "Bedeviyle")
N("Ivy Root", GEN_M, "Sarmaşık Kökü", "Sarmaşık Kökleri", "Sarmaşık Kökünü", "Sarmaşık Köküyle")
N("Active Ivy", GEN_M, "Canlı Sarmaşık", "Canlı Sarmaşıklar", "Canlı Sarmaşığı", "Canlı Sarmaşığıyla")
N("Ivy Branch", GEN_F, "Sarmaşık Dalı", "Sarmaşık Dalları", "Sarmaşık Dalını", "Sarmaşık Dalıyla")
N("Dormant Ivy", GEN_M, "Uyuyan Sarmaşık", "Uyuyan Sarmaşıklar", "Uyuyan Sarmaşığı", "Uyuyan Sarmaşıkla")
N("Ivy N", GEN_M, "sarmaşık N", "Sarmaşıklar N", "Sarmaşığı N" , "Sarmaşıkla N")
N("Ivy D", GEN_M, "Sarmaşık D", "sarmaşıklar D", "Sarmaşığı D", "Sarmaşıkla D")
N("Giant Ape", GEN_F, "Dev Maymun", "Dev Maymunlar", "Dev Maymunu", "Dev Maymunla")
N("Slime Beast", GEN_F, "Balçık Canavarı", "Balçık Canavarları", "Balçık Canavarını", "Balçık Canavarıyla")
N("Mirror Image", GEN_N, "Yansıma", "Yansımalar", "Yansımayı", "Yansımayla")
N("Mirage", GEN_M, "Yansı", "Yansılar", "Yansıyı", "Yansıyla")
N("Golem", GEN_M, "Golem", "Golemler", "Golemi", "Golemle")
N("Eagle", GEN_M, "Kartal", "Kartallar", "Kartalı", "Kartalla")
N("Seep", GEN_M, "Sızıntı", "Sızıntılar", "Sızıntıyı" , "Sızıntıyla")
N("Zombie", GEN_M, "Hortlak", "Hortlaklar", "Hortlağı", "Hortlakla")
N("Ghost", GEN_M, "Hayalet", "Hayaletler", "Hayaleti" , "Hayaletle")
N("Necromancer", GEN_M, "Ölüçağıran", "Ölüçağıranlar", "Ölüçağıranı", "Ölüçağıranla")
N("Shadow", GEN_M, "Gölge", "Gölgeler", "Gölgeyi", "Gölgeyle")
N("Tentacle", GEN_M, "Dokunaç", "Dokunaçlar", "Dokunacı", "Dokunaçla")
N("Tentacle Tail", GEN_M, "Dokunaç Devamı", "Dokunaç Devamları", "Dokunaç Devamını", "Dokunaç Devamıyla")
N("Tentacle W", GEN_M, "Dokunaç W", "Dokunaçlar W", "Dokunacı W", "Dokunaçla W")
N("Cultist", GEN_M, "Mürit", "Müritler", "Müridi", "Müritle")
N("Fire Cultist", GEN_M, "Ateş Müridi", "Ateş Müritleri", "Ateş Müridini", "Ateş Müritle")
N("Greater Demon", GEN_M, "Büyük Şeytan", "Büyük Şeytanlar", "Büyük Şeytanı", "Büyük Şeytanla")
N("Lesser Demon", GEN_M, "Küçük Şeytan", "Küçük Şeytanlar", "Küçük Şeytanı", "Küçük Şeytanla")
N("Ice Shark", GEN_M, "Buz Köpekbalığı", "Buz Köpekbalıkları", "Buz Köpekbalığını", "Buz Köpekbalığıyla")
N("Running Dog", GEN_M, "Koşan Köpek", "Koşan Köpekler", "Koşan Köpeği", "Koşan Köpekle")
N("Demon Shark", GEN_M, "Şeytan Köpekbalığı", "Şeytan Köpekbalıkları", "Şeytan Köpekbalığını","Şeytan Köpekbalığıyla")
N("Fire Fairy", GEN_F, "Ateş Perisi", "Ateş Perileri", "Ateş Perisini", "Ateş Perisiyle")
N("Crystal Sage", GEN_M, "Buz Piri", "Buz Pirleri", "Buz Pirini", "Buz Piriyle")
N("Hedgehog Warrior", GEN_M, "Kirpi Savaşçı", "Kirpi Savaşçılar", "Kirpi Savaşçıyı", "Kirpi Savaşçıyla")
N("Tentacle (withdrawing)", GEN_F, "Dokunaç (geri çekiliyor)", "Dokunaçlar (geri çekiliyor)", "Dokunacı (geri çekiliyor)","Dokunaçla (geri çekiliyor)")
N("Ice Diamond", GEN_O, "Buz Elması", "Buz Elmasları", "Buz Elmasını", "Buz Elmasıyla")
N("Gold", GEN_N, "Altın", "Altınlar", "Altını","Altınla")
N("Spice", GEN_F, "Baharat", "Baharatlar", "Baharatı","Baharatla")
N("Ruby", GEN_O, "Yakut", "Yakutlar", "Yakutu", "Yakutla")
N("Elixir of Life", GEN_O, "Yaşam İksiri", "Yaşam İksirleri", "Yaşam İksirini", "Yaşam İksiriyle")
N("Shard", GEN_O, "Cam Parçası", "Cam Parçaları", "Cam Parçasını", "Cam Parçasıyla")
N("Necromancer's Totem", GEN_O, "Ölüçağıran Totemi", "Ölüçağıran Totemleri", "Ölüçağıran Totemini", "Ölüçağıran Totemiyle")
N("Demon Daisy", GEN_F, "Şeytan Papatyası", "Şeytan Papatyaları", "Şeytan Papatyasını", "Şeytan Papatyasıyla")
N("Statue of Cthulhu", GEN_F, "Cthulhu Heykeli", "Cthulhu Heykelleri", "Cthulhu Heykelini", "Cthulhu Heykeliyle")
N("Phoenix Feather", GEN_N, "Anka Kuşu Tüyü", "Anka Kuşu Tüyleri", "Anka Kuşu Tüyünü", "Anka Kuşu Tüyüyle")
N("Ice Sapphire", GEN_O, "Buz Safiri", "Buz Safirleri", "Buz Safirini", "Buz Safiriyle")
N("Hyperstone", GEN_O, "Aşkıntaş", "Aşkıntaşlar", "Aşkıntaşı", "Aşkıntaşla")
// N("Hyperstone", GEN_O, "Üstüntaş", "Üstüntaşlar", "Üstüntaşı", "Üstüntaşla")
N("Key", GEN_O, "Anahtar", "Anahtarlar", "Anahtarı", "Anahtarla")
 N("Dead Orb", GEN_F, "Ölü Küre", "Ölü Küreler", "Ölü Küreyle", "Ölü Küreyi")

// ORBS
// ====

N("Orb of Yendor", GEN_F, "Yendor Küresi", "Yendor Küreleri", "Yendor Küresini", "Yendor Küresiyle")
N("Orb of Storms", GEN_F, "Fırtına Küresi", "Fırtına Küreleri", "Fırtına Küresini", "Fırtına Küresiyle")
N("Orb of Flash", GEN_F, "Şimşek Küresi", "Şimşek Küreleri", "Şimşek Küresini", "Şimşek Küresiyle")
N("Orb of Winter", GEN_F, "Kış Küresi", "Kış Küreleri", "Kış Küresini", "Kış Küresiyle")
N("Orb of Speed", GEN_F, "Hız Küresi", "Hız Küreleri", "Hız Küresini", "Hız Küresiyle")
N("Orb of Life", GEN_F, "Yaşam Küresi", "Yaşam Küreleri", "Yaşam Küresini", "Yaşam Küresiyle")
N("Orb of Shielding", GEN_F, "Kalkan Küresi", "Kalkan Küreleri", "Kalkan Küresini", "Kalkan Küresiyle")
// N("Orb of Digging", GEN_F, "Kazma Küresi", "Kazma Küreleri", "Kazma Küresini", "Kazma Küresiyle")
N("Orb of Teleport", GEN_F, "Işınlanma Küresi", "Işınlanma Küreleri", "Işınlanma Küresini", "Işınlanma Küresiyle")
N("Orb of Safety", GEN_F, "Güvenlik Küresi", "Güvenlik Küreleri", "Güvenlik Küresini", "Güvenlik Küresiyle")
N("Orb of Thorns", GEN_F, "Diken Küresi", "Diken Küreleri", "Diken Küresini", "Diken Küresiyle")
 N("Fern Flower", GEN_O, "Eğreltiotu Çiçeği", "Eğreltiotu Çiçekleri", "Eğreltiotu Çiçeğini", "Eğreltiotu Çiçeğiyle")

// TERRAIN FEATURES
// ================

N("none", GEN_O, "hiç", "hiçler", "hiçi", "hiçle")
N("ice wall", GEN_F, "Buzdan Duvar", "Buzdan Duvarlar", "Buzdan Duvarı", "Buzdan Duvarda")
N("great wall", GEN_F, "Çin Seddi", "Çin Setleri", "Çin Seddini", "Çin Seddinde")
N("red slime", GEN_F, "Kırmızı Balçık", "Kırmızı Balçıklar", "Kırmızı Balçığı", "Kırmızı Balçıkta")
N("blue slime", GEN_F, "Mavi Balçık", "Mavi Balçıklar", "Mavi Balçığı", "Mavi Balçıkta")
N("living wall", GEN_F, "Canlı Duvar", "Canlı Duvarlar", "Canlı Duvarı", "Canlı Duvarda")
N("living floor", GEN_F, "Canlı Zemin", "Canlı Zeminler", "Canlı Zemini", "Canlı Zeminde")
N("dead troll", GEN_M, "Ölü Trol" ,"Ölü Troller", "Ölü Trolü", "Ölü Trolle")
N("sand dune", GEN_F, "Kumul", "Kumullar", "Kumulu", "Kumulda")
N("Magic Mirror", GEN_N, "Sihirli Ayna", "Sihirli Aynalar", "Sihirli Aynayı", "Sihirli Aynayla")
N("Cloud of Mirage", GEN_F, "Bulut Yansısı", "Bulut Yansıları", "Bulut Yansısını", "Bulut Yansısıyla")
N("Thumper", GEN_O, "Gümleyen", "Gümleyenler", "Gümleyeni", "Gümleyenle")
N("Bonfire", GEN_N, "Kamp Ateşi", "Kamp Ateşleri", "Kamp Ateşini", "Kamp Ateşiyle")
N("ancient grave", GEN_O, "Antik Mezar", "Antik Mezarlar", "Antik Mezarı", "Antik Mezarda")
N("fresh grave", GEN_O, "Taze Mezar", "Taze Mezarlar", "Taze Mezarı", "Taze Mezarda")
N("column", GEN_F, "Sütun", "Sütunlar", "Sütunu", "Sütunla")
N("lake of sulphur", GEN_N, "Sülfür Gölü", "Sülfür Gölleri", "Sülfür Gölünü", "Sülfür Gölünde")
N("lake", GEN_N, "Göl", "Göller", "Gölü", "Gölde")
N("frozen lake", GEN_N, "Donmuş Göl", "Donmuş Göller", "Donmuş Gölü", "Donmuş Gölde")
N("chasm", GEN_N, "Uçurum", "Uçurumlar", "Uçurumu", "Uçurumda")
N("big tree", GEN_N, "Büyük Ağaç", "Büyük Ağaçlar", "Büyük Ağacı", "Büyük Ağaçla")
N("tree", GEN_N, "Ağaç", "Ağaçlar", "Ağacı", "Ağaçla")

// LANDS
// =====

N("Great Wall", GEN_N, "Yüksek Duvar", "Yüksek Duvarlar", "Yüksek Duvarı", "Yüksek Duvarda")
N("Crossroads", GEN_N, "Arayollar", "Arayollar", "Arayolları", "Arayollarda")
N("Desert", GEN_F, "Çöl", "Çöller", "Çölü", "Çölde")
N("Icy Land", GEN_F, "Buz Diyarı", "Buz Diyarları", "Buz Diyarını", "Buz Diyarında")
N("Living Cave", GEN_F, "Yaşayan Mağara", "Yaşayan Mağaralar", "Yaşayan Mağarayı", "Yaşayan Mağarada")
N("Jungle", GEN_F, "Vahşi Orman", "Vahşi Ormanlar", "Vahşi Ormanı", "Vahşi Ormanda")
N("Alchemist Lab", GEN_N, "Laboratuar", "Laboratuarlar", "Laboratuarı", "laboratuarda")
N("Mirror Land", GEN_F, "Aynalar Diyarı", "Aynalar Diyarları", "Aynalar Diyarını", "Aynalar Diyarında")
N("Graveyard", GEN_O, "Mezarlık", "Mezarlıklar", "Mezarlığı", "Mezarlıkta")
N("R'Lyeh", GEN_N, "R'Lyeh", "R'Lyeh", "R'Lyeh", "R'Lyeh")
N("Hell", GEN_N, "Cehennem", "Cehennemler", "Cehennemi", "Cehennemde")
N("Cocytus", GEN_M, "Kokitos", "Kokitoslar", "Kokitosu", "Kokitosta")
N("Land of Eternal Motion", GEN_N, "Sonsuz Devinim Diyarı", "Sonsuz Devinim Diyarları", "Sonsuz Devinim Diyarını", "Sonsuz Devinim Diyarında")
N("Dry Forest", GEN_M, "Kara Orman", "Kara Ormanlar", "Kara Ormanı", "Kara Ormanda")
N("Game Board", GEN_F, "Tahta", "Tahtalar", "Tahtayı", "Tahtada")

// GAME MESSAGES
// =============

// fighting messages
// -----------------

// ablative !

S("You kill %the1.", "%a1 öldürdün.")
S("You would be killed by %the1!", "%1 tarafından öldürülürsün!")
S("%The1 would get you!", "%1 seni kapar!")
S("%The1 destroys %the2!", "%1 %a2 yok etti!")
S("%The1 eats %the2!", "%1 %a2 yedi!")
S("The ivy destroys %the1!", "Samaşık %a1 yok etti!")
S("%The1 claws %the2!", "%1 %a2 pençeledi!")
S("%The1 scares %the2!", "%1 %a2 korkuttu!")
S("%The1 melts away!", "%1 eridi!")
S("%The1 stabs %the2.", "%1 %2 bıçakladı.")
S("You stab %the1.", "%a1 bıçakladın.")

S("You cannot attack %the1 directly!", "%a1 doğrudan öldüremezsiniz!")
S("Stab them by walking around them.", "Etrafında yürüyerek bıçaklayın.")

S("You feel more experienced in demon fighting!", "Şeytanlarla savaşmada daha deneyimli hissediyorsun!")
S("Cthulhu withdraws his tentacle!", "Cthulhu dokungacını çekti!")
S("The sandworm explodes in a cloud of Spice!", "Kumkurdu patladı ve etrafa baharat saçtı!")
S("%The1 is confused!", "%1 sersemledi.")
S("%The1 raises some undead!", "%1 ölü çağırdı!")
S("%The1 throws fire at you!", "%1 sana ateş attı!")
S("%The1 shows you two fingers.", "%1 sana iki parmağını gösterdi.")
S("You wonder what does it mean?", "Bunun ne demek olduğunu merak ettin")
S("%The1 shows you a finger.", "%1 sana parmak hareketi yaptı.")
S("You think about possible meanings.", "Bunun olası anlamlarını düşündün.")
S("%The1 moves his finger downwards.", "%1 parmağını aşağı doğru hareket ettirdi.")
S("Your brain is steaming.", "Beynin kaynıyor.")
S("%The1 destroys %the2!", "%1  %a2 yok etti!")
S("You join %the1.", "%abl1 bütünleştin.")
S("Two of your images crash and disappear!", "İki yansıma çarpıştı ve yok oldu!")
S("%The1 breaks the mirror!", "%1 aynayı kırdı!")
S("%The1 disperses the cloud!", "%1 bulutun içerisinde kayboldu!")
S("You activate the Flash spell!", "Işık büyüsünü etkinleştirdin!")
S("You activate the Lightning spell!", "Şimşek büyüsünü etkinleştirdin!")
S("Ice below you is melting! RUN!", "Altındaki buz eriyor! KAÇ!")
S("This spot will be burning soon! RUN!", "Bu nokta yakında yanacak! KAÇ!")
S("The floor has collapsed! RUN!", "Zemin çöktü! KAÇ!")
S("You need to find the right Key to unlock this Orb of Yendor!",
  "Bu Yendorun Küresinin kilidini açmak için bir anahtara ihtiyacın var!")
S("You fall into a wormhole!", "Bir solucan deliğine düştün!")
S("You activate %the1.", "%a1 aktifleştirdin.")
S("No room to push %the1.", "%a1 itmek için yeterince yer yok.")
S("You push %the1.", "%a1 ittirdin.")
S("You start chopping down the tree.", "Ağacı kesmeye başladın.")
S("You chop down the tree.", "Ağacı kestin.")
S("You cannot attack Sandworms directly!", "Kumkurduna doğrudan saldıramazsınız!")
S("You cannot attack Tentacles directly!", "Dokungaçlara doğrudan saldıramazsın!")
S("You cannot defeat the Shadow!", "gölgeyi henüz yenemezsiniz!")
S("You cannot defeat the Greater Demon yet!", "Büyük Şeytanı henüz yenemezsiniz!")
S("That was easy, but groups could be dangerous.", "Bu kolaydı, ama gruplar daha tehlikeli olabilir.")
S("Good to know that your fighting skills serve you well in this strange world.", "Dövüş yeteneklerinin bu garip dünyada hâlâ işe yaradığını bilmek güzel.")
S("You wonder where all these monsters go, after their death...", "Bütün bu canavarların ölümlerinden sonra nereye gittiklerini merak ediyorsun...")
S("You feel that the souls of slain enemies pull you to the Graveyard...", "Katlettiğin düşmanların ruhlarının seni mezarlığa çektiğini hissediyorsun...")
S("Wrong color!", "Yanlış renk!")

// this one is a bit problematic
S("You cannot move through %the1!", "%1 hücresinden geçemezsin!")
// S("You cannot move through %the1!", "%abl1n geçemezsin!")
S("%The1 would kill you there!", "%1 orada seni hemencecik öldürür!")
S("Wow! %1! This trip should be worth it!", "Vay canına! %1! Bu seyahati yaptığına değecek!")
S("For now, collect as much treasure as possible...", "Şimdilik mümkün olduğunca fazla hazine topla...")
S("Prove yourself here, then find new lands, with new quests...", "Kendini burada kanıtla, sonra yeni görevlerle yeni diyarlar keşfet...")
S("You collect your first %1!", "%a1 topladın. Bu senin ilkin!")
S("You have found the Key! Now unlock this Orb of Yendor!", "Anahtarı buldun! Bu Yendorun Küresinin kilidini açabilirsin!")
S("This orb is dead...", "Bu küre ölü...")
S("Another Dead Orb.", "Başka bir Ölü Küre.")
S("You have found %the1!", "%a1 buldun!")

// THIS ONE IS A BIT PROBLEMATIC
S("You feel that %the2 become%s2 more dangerous.", "Topladığın her %abl1, ...")
S("With each %1 you collect...", "%2 gittikçe daha tehlikeli bir hâl alıyor...")
S("Are there any magical orbs in %the1?...", "%abl1 başka sihirli küre var mı?")
S("You feel that %the1 slowly become%s1 dangerous...", "%1 yavaşça daha tehlikeli bir hâl alıyor...")
S("Better find some other place.", "Başka bir yer bulsan daha iyi olacak.")
S("You have a vision of the future, fighting demons in Hell...", "Geleceğini gördün, Cehennemde şeytanlarla savaşıyordun...")
S("With this Elixir, your life should be long and prosperous...", "Bu İksirle hayatın uzun ve refah olacak...")
S("The Necromancer's Totem contains hellish incantations...", "Ölüçağıranın Totemi şeytani işlemelerle doluydu...")
S("The inscriptions on the Statue of Cthulhu point you toward your destiny...", "Cthulhu'nun heykeli üzerindeki yazıt sana kaderinin nasıl çizileceğini gösteriyor...")
S("Still, even greater treasures lie ahead...", "İleride daha bile çok hazine seni bekliyor...")
S("You collect %the1.", "%a1 aldın.")
S("CONGRATULATIONS!", "TEBRIKLER!")
S("Collect treasure to access more different lands...", "Başka diyarlara ulaşmak için hazine topla...")
S("You feel that you have enough treasure to access new lands!", "Yeni diyarlara ulaşmak için yeterince hazinen olduğunu düşünüyorsun!")
S("Collect more treasures, there are still more lands waiting...", "Daha fazla hazine topla, hâlâ seni bekleyen diyarlar var...")
S("You feel that the stars are right, and you can access R'Lyeh!", "Yıldızlar sana, R'Lyeh'e ulaşabileceğini söylüyor!")
S("Kill monsters and collect treasures, and you may get access to Hell...", "Canavarlar öldür, hazineler topla ve belki Cehenneme erişebilirsin...")
S("To access Hell, collect %1 treasures each of %2 kinds...", "Cehenneme erişmek için her %2 hazine tipinden %1'ar tane toplamalısın...")
S("Abandon all hope, the gates of Hell are opened!", "Umutlar tükendi, Cehennemin kapıları açıldı!")
S("And the Orbs of Yendor await!", "Yendorun Küresi seni bekliyor!")
S("You switch places with %the1.", "%abl1 yer değiştirdin.")
S("You rejoin %the1.", "%abl1 bütünleştin.")
S("The mirror shatters!", "Ayna kırıldı!")
S("The cloud turns into a bunch of images!", "Bulut pek çok görüntüye dönüştü!")
S("The slime reacts with %the1!", "Balçık %abl1 etkileşime girdi!")
S("You drop %the1.", "%a1 düşürdün.")
S("You feel great, like a true treasure hunter.", "Şahane hissediyorsun. Sanki gerçek bir hazine avcısı gibi.")
S("Your eyes shine like gems.", "Gözlerin mücevherler gibi ışıldıyor.")
S("Your eyes shine as you glance at your precious treasures.", "Değerli hazinelerine bakarken gözlerin ışıldadı.")
S("You glance at your great treasures.", "Müthiş hazinelerine göz gezdirdin.")
S("You glance at your precious treasures.", "Değerli hazinelerine şöyle bir baktın.")
S("You glance at your precious treasure.", "Hazinene şöyle bir baktın.")
S("Your inventory is empty.", "Envanterin boş.")
S("You teleport to a new location!", "Yeni bir yere ışınlandın!!")
S("Could not open the score file: ", "Puan dosyası açılamadı: ")
S("Game statistics saved to %1", "İstatistikler %1 konumuna kaydedildi.")
S("Game loaded.", "Oyun yüklendi.")
S("You summon some Mimics!", "Taklitçiler çağırdın!")
S("You summon a golem!", "Bir golem çağırdın!")
S("You will now start your games in %1", "Şimdi oyunlarını %abl1 başlatacaksın.")
S("Activated the Hyperstone Quest!", "Aşkıntaş Görevini etkinleştirdin!")
S("Orb power depleted!", "Küre gücü tükendi!")
S("Orbs summoned!", "Küreler çağırdın!")
S("Orb power gained!", "Küre gücü kazandın!")
S("Dead orbs gained!", "Ölü Küreler kazandın!")
S("Orb of Yendor gained!", "Yendorun Orbu kazandın!")
S("Treasure gained!", "Hazine kazanıldı!")
S("Lots of treasure gained!", "Bir sürü hazine kazandın!")
S("You summon a sandworm!", "Bir kumkurdu çağırdın!")
S("You summon an Ivy!", "Bir sarmaşık oluşturdun!")
S("You summon a monster!", "Bir canavar oluşturdun!")
S("You summon some Thumpers!", "Gümleyenler oluşturdun")
S("You summon a bonfire!", "Bir kamp ateşi oluşturdun!")
S("Treasure lost!", "Hazine kayboldu!")
S("Kills gained!", "Leşler kazandınız!")
S("Activated Orb of Safety!", "Güvenlik Küresini aktifleştirdin.")
S("Teleported to %1!", "%loc1 e ışınlandın.")

S("Welcome to HyperRogue", "HyperRogue'a hoşgeldin")
S(" for Android", " Android için")
S(" for iOS", " iOS için")
S("! (version %1)\n\n", "! (versiyon %1)\n\n")
S(" (press ESC for some hints about it).", " (ESC ile hakkında yardıma ulaşabilirsin).")
S("Press 'c' for credits.", "Yapımcılar için 'c'ye bas.")
S("game design, programming, texts and graphics by Zeno Rogue <zeno@attnam.com>\n\n",
  "tasarım, programlama, metinler ve grafikler: Zeno Rogue <zeno@attnam.com>\n\n")
S("add credits for your translation here", "Çeviri: zulmetefza & Seyacim\n\n")
S(" (touch to activate)", " (etkinleştirmek için dokun)")
S(" (expired)", " (zaman aşımı)")
S(" [%1 turns]", " [Tur: %1]")
S(", you", ", Sen")
S("0 = Klein model, 1 = Poincaré model", "0 = Klein modeli, 1 = Poincaré modeli")
S("you are looking through it!", "Hiperboloidin içinden bakıyorsun!")
S("simply resize the window to change resolution", "pencerenin boyutunu değiştirerek çözünürlüğü değiştirebilirsin.")
S("[+] keep the window size, [-] use the screen resolution", "[+] pencere boyutunu koru, [-] ekran çözünürlüğünü kullan")
S("+5 = center instantly, -5 = do not center the map", "+5 = anında merkeze al, -5 = merkezleme")
S("press Space or Home to center on the PC", "Space veya Home'a basarak PC'ye odakla.")
S("You need special glasses to view the game in 3D", "Oyunu 3D'de görüntülemek için özel gözlüklere ihtiyacın var.")
S("You can choose one of the several modes", "Farklı modlardan birini seçebilirsin.")
S("ASCII", "ASCII")
S("black", "siyah")
S("plain", "düz")
S("Escher", "Escher")
S("items only", "tylko przedmioty")
S("items and monsters", "eşyalar ve canavarlar")
S("no axes", "eksen yok")
S("auto", "otomatik")
S("light", "hafif")
S("heavy", "ağır")
S("The axes help with keyboard movement", "Eksenler klavye hareketine yardım eder.")
S("Config file: %1", "Ayar dosyası: %1")
S("joystick mode: automatic (release the joystick to move)", "oyun kolu modu: otomatik (kolu bırakarak hareket edersin)")
S("joystick mode: manual (press a button to move)", "oyun kolu modu: manuel (bir düğmeye basarak hareket edersin)")
S("Reduce the framerate limit to conserve CPU energy", "CPU enerjisinden tasarruf etmek için kare sayısı sınırını azalt.")
S("Press F1 or right click for help", "F1 ya da sağ tık ile yardıma ulaş.")
S("No info about this...", "Hakkında bir bilgi yok...")
S("Press Enter or F10 to save", "Enter ya da F10 ile kayıt et")
S("Press Enter or F10 to quit", "Enter ya da F10 ile çık")
S("or 'r' or F5 to restart", "'r' veya F5 ile yeniden başlat")
S("or 't' to see the top scores", "'t'  ile yüksek puanları gör")
S("or another key to continue", "veya devam etmek için başka bir tuşa bas.")
S("It is a shame to cheat!", "Seni Hilekâr!")
S("Showoff mode", "Gösteriş Modu")
S("Quest status", "Görev durumu")
S("GAME OVER", "OYUN BİTTİ")
S("Your score: %1", "Puanın: %1")
S("Enemies killed: %1", "Öldürülen Düşmanlar: %1")
S("Orbs of Yendor found: %1", "Bulunan Yendor Küresi sayısı: %1")
S("Collect %1 $$$ to access more worlds", "%1 $$$ toplayarak başka dünyalara eriş")
// S("Collect %1 $$$ to access R'Lyeh and Dry Forest", "60 $$$ toplayarak R'Lyeh ve Kara Ormana eriş.")
S("Collect at least %1 treasures in each of %2 types to access Hell", "%2 hazine çeşidinin hepsinden %1'ar tane toplayarak Cehenneme erişebilirsin.")
S("Collect at least %1 Demon Daisies to find the Orbs of Yendor", "%1 Şeytan Papatyası toplayarak Yendorun Kürelerini bulabilirsin.")
S("Hyperstone Quest: collect at least %3 %1 in %the2", "Aşkıntaş Görevi: %2'de en az %3 hazine topla.")
S("Hyperstone Quest completed!", "Aşkıntaş görevi tamamlandı.")
S("Look for the Orbs of Yendor in Hell or in the Crossroads!", "Yendorun Küreleri için Cehennemi yahut Arayolları ara!")
S("Unlock the Orb of Yendor!", "Yendor'un küresinin kilidini aç!")
S("Defeat %1 enemies to access the Graveyard", "Mezarlığa erişmek için %1 düşman öldür.")
S("(press ESC during the game to review your quest)", "(Görevine bakmak için oyun sırasında ESC'ye bas.)")
S("you have cheated %1 times", "şimdiye kadar %1 kez hile yaptın.")
S("%1 turns (%2)", "tur sayısı: %1 (%2)")
S("last messages:", "son mesajlar: ")
S("time elapsed", "geçen zaman")
S("date", "tarih")
S("treasure collected", "toplanan hazineler")
S("total kills", "toplam leşler")
S("turn count", "tur sayacı")
S("cells generated", "üretilen hücreler")
S("t/left/right - change display, up/down - scroll, s - sort by", "t/sol/sağ - görünümü değiştir, yukarı/aşağı - kaydır, s - sırala")
S("kills", "leşler")
S("time", "zaman")
S("ver", "ver")
S("SORT", "SIRALA")
S("PLAY", "OYNA")
S("Your total wealth", "Toplam servetiniz")
S("treasure collected: %1", "toplanan hazine: %1")
S("objects found: %1", "bulunan eşyalar: %1")
S("orb power: %1", "küre gücü: %1")
S(" (click to drop)", " (bırakmak için tıkla)")
S("You can also scroll to the desired location and then press 't'.", "İstersen görüntüyü isteidğin yere çekip sonra 't'ye basabilirsin.")
S("Thus, it is potentially useful for extremely long games, which would eat all the memory on your system otherwise.\n",
  "Yani, bu olası çok uzun, sistemin tüm hafızasını tüketecek oyunlarında yardımcı olabilir.")
S("You can touch the Dead Orb in your inventory to drop it.", "Ölü Küreye dokunarak onu bırakabilirsin.")
S("This might be useful for Android devices with limited memory.", "Bu, sınırlı hafızalı Android cihazları için kullanışlı olabilir.")
S("You can press 'g' or click them in the list to drop a Dead Orb.", "'g' ye basarak veya listede tıklayarak bir Ölü Küreyi bırakabilirsin.")
S("frames per second", "saniye başına kare")
S("monsters killed: %1", "öldürülen canavarlar: %1")
S("Drawing %1 (layer %2), F1 for help", "%1 çiziliyor (katman %2), F1 - yardım")
S("hepta floor", "heptazemin")
S("hexa floor", "hekzazemin")
S("character", "karakter")
S("ESC for menu/quest", "ESC - menü/görev")
S("vector graphics editor", "vektör grafiği editörü")
S("cheat mode", "hile modu")
S("heptagonal game board", "yedigensel tahta")
S("triangular game board", "üçgensel tahta")
S("HyperRogue game board", "HyperRogue tahta")
S("first page [Space]", "ilk sayfa [Space]")
S("Configuration:", "AYARLAR:")
S("video resolution", "çözünürlük")
S("fullscreen mode", "tam ekran modu")
S("animation speed", "animasyon hızı")
S("dist from hyperboloid ctr", "hiperboloid merkezinden uzaklık")
S("scale factor", "ölçek faktörü")
S("wall display mode", "duvar görünümü")
S("monster display mode", "canavar görünümü")
S("cross display mode", "yıldız görünümü")
S("background music volume", "müzik seviyesi")
S("OFF", "KAPALI")
S("ON", "AÇIK")
S("distance between eyes", "gözler arası uzaklık")
S("framerate limit", "kare sayısı sınırı")
S("joystick mode", "oyun kolu modu")
S("automatic", "otomatik")
S("manual", "kılavuz")
S("language", "dil")
S("EN", "TR")
S("player character", "oyuncunun karakteri")
S("male", "erkek")
S("female", "kadın")
S("use Shift to decrease and Ctrl to fine tune ", "Shift'le azalt, Ctrl ile ince ayar yap.")
S("(e.g. Shift+Ctrl+Z)", " (Meselâ Shift+Ctrl+Z)")
S("the second page [Space]", "ikinci sayfa [Space]")
S("special features [Space]", "özel seçenekler [Space]")
S("see the help screen", "yardım ekranına bak.")
S("save the current config", "mevcut ayarları kaydet")
S("(v) config", "(v) ayarlar")
S("Screenshot saved to %1", "Ekran görüntüsü %1 konumuna kaydedildi.")
S("You need an Orb of Teleport to teleport.", "Işınlanmak için Işınlanma Küresine ihtiyacın var.")
S("Use arrow keys to choose the teleport location.", "Işınlanacağın yeri seçmek için okları kullan.")
S("openGL mode enabled", "OpenGL modu devrede")
S("openGL mode disabled", "OpenGL modu devredışı")
S("anti-aliasing enabled", "Anti=alising devrede/")
S("anti-aliasing disabled", "Anti-aliasing devredışı")
S("You activate your demonic powers!", "Şeytani güçlerini aktifleştirdin!")

// Steam messages
// --------------

S("New Achievement:", "Yeni Başarım:")
S("Your total treasure has been recorded in the Steam Leaderboards.", "Toplam hazinen Steam Listelerine kaydedildi.")
S("Congratulations!", "Tebrikler!")
S("You have improved your total high score and %1 specific high scores!", "Toplam yüksek puanını ve %1 farklı tekil puanını artırdın!")
S("You have improved your total and '%1' high score!", "Toplam yüksek puanını ve '%P1!' puanını artırdın!")
S("You have improved your total high score on Steam. Congratulations!", "Steam'deki toplam yüksek puanını artırdın. Tebrikler!")
//S("You have improved %1 of your specific high scores!", "Tekil yüksek skorlarınızdan %1 tanesini artırdın !")
S("You have improved %1 of your specific high scores!", "Tekil yüksek skorlarından %1 tanesini artırdın !")
S("You have improved your '%1' high score on Steam!", "Steam'deki '%P1'puanını artırdın!")
S("You have collected 10 treasures of each type.", "her hazine çeşidinden onar tane topladın.")
S("This is your first victory!", "Bu senin ilk zaferin!")
S("This has been recorded in the Steam Leaderboards.", "Bu Steam Listelerine kaydedildi.")
S("The faster you get here, the better you are!", "Daha hızlı demek, daha iyi demek !")
S("You have improved both your real time and turn count. Congratulations!", "Hem gerçek zamanını hem de tur sayını geliştirdin! Tebrikler! ")
S("You have used less real time than ever before. Congratulations!", "Bu her zamankinden daha az zaman aldı! Tebrikler!")
S("You have used less turns than ever before. Congratulations!", "Her zamankinden daha az sayıda tur kullandın! Tebrikler! ")

// help texts
// ----------

// These are separated into multiple lines just for convenience,
// you don't have to follow.

S(
 "You have been trapped in a strange, non-Euclidean world. Collect as much treasure as possible "
 "before being caught by monsters. The more treasure you collect, the more "
 "monsters come to hunt you, as long as you are in the same land type. The "
 "Orbs of Yendor are the ultimate treasure; get at least one of them to win the game!",

"Garip ve Ökliddışı bir dünyada hapsoldun. Canavarlar tarafından yakalanmadan önce olabildiğince hazine topla."
 "Aynı arazi tipinde daha fazla hazine topladıkça,daha fazla canavar sana saldıracak."
 "Yendor'un küreleri nihai hazinelerdir, onlardan bir tane ile oyunu kazanabilirsin!"
 )

S(
 "You can fight most monsters by moving into their location. "
 "The monster could also kill you by moving into your location, but the game "
 "automatically cancels all moves which result in that.\n\n",

 "Çoğu canavarın yerine ilerleyerek onu öldürebilirsin. Canavar da seni senin bulunduğun yere ilerleyerek öldürebilir, ama oyun böyle hamlelere zaten izin vermez.\n\n")

S(
 "Usually, you move by touching somewhere on the map; you can also touch one "
 "of the four buttons on the map corners to change this (to scroll the map "
 "or get information about map objects). You can also touch the "
 "numbers displayed to get their meanings.\n",
 "Normalde haritada bir yere dokunarak hareket edersin, haritanın dört köşesindeki tuşlara dokunarak bunu değiştirebilirsin."
" (haritayı çevirmek ya da haritadaki nesneler hakkında bilgi almak için). Gösterilen numaralara dokunarak da anlamlarını görebilirsin. \n")

S("Move with mouse, num pad, qweadzxc, or hjklyubn. Wait by pressing 's' or '.'. Spin the world with arrows, PageUp/Down, and Space. "
 "To save the game you need an Orb of Safety. Press 'v' for the main menu (configuration, special modes, etc.), ESC for the quest status.\n\n",
 "Fareyle, sayı tuşlarıyla, qweadzxc ile, veya hjklyubn ile hareket et.  's' ya da '.' ile bekle. "
 "Oklarla, PageUp/Down ile veya Space ile dünyayı çevirebilirsin. Oyunu kaydetmek için Güvenlik Küresine ihtiyacın var. Ayarlar için 'v'ye görev durumu ve menü için 'ESC'ye bas.\n\n")

S("See more on the website: ", "Daha fazlasını websitesinde görüntüleyin: ")

S(
  "special thanks to the following people for their bug reports, feature requests, porting, and other help:\n\n%1\n\n",
  "Hata bildirimleri, özellik istekleri, portlama ve diğer yardımları için şu kişilere teşekkürler: %1  \n\n")

S(
 "The total value of the treasure you have collected.\n\n"
 "Every world type contains a specific type of treasure, worth 1 $$$; "
 "your goal is to collect as much treasure as possible, but every treasure you find "
 "causes more enemies to hunt you in its native land.\n\n"
 "Orbs of Yendor are worth 50 $$$ each.\n\n",

  "Topladığınız hazinelerin toplam değeri.\n\n"
  "Her dünya 1 $$$ değerinde belli bir çeşit hazine içerir;  "
  "amacın olabildiğince çok hazine toplamak, ama her bulduğun hazine, daha fazla düşmanın sana saldırmasına sebep olur.\n\n "
  "Her Yendorun Küresi 50 $$$ değerindedir.\n\n")

S(
 "The higher the number, the smoother the animations in the game. "
 "If you find that animations are not smooth enough, you can try "
 "to change the options ",
 "Daha yüksek sayı, daha akıcı animasyonlr demektir. "
 "Eğer animasyonlar senin için yeterince akıcı değilse, ayarları değiştirmeyi düşünebilirsin")

S("(Menu button) and select the ASCII mode, which runs much faster. "
 "Depending on your device, turning the OpenGL mode on or off might "
 "make it faster, slower, or cause glitches.",
 "(Menü), ve ASCII modunu seçebilirsin. Bu mod daha hızlı çalışır. Aygıtınıza bağlı olarak OpenGL'yi açmak oyununuzu hızlandırabilir, yavaşlatabilir veya hatalara sebep olabilir."
 )

S("(in the MENU). You can reduce the sight range, this should make "
 "the animations smoother.",
 "(MENÜDE). Görüş aralığını seçebilirsin. Bu animasyonları daha akıcı hâle getirebilir.")

S("(press v) and change the wall/monster mode to ASCII, or change "
 "the resolution.",
 "('v'ye bas) ve duvar ve canavar modunu ASCII'ye çevir veya çözünnürlüğü değiştir.")

S(
 "In this mode you can draw your own player character and floors. "
 "Mostly for the development purposes, but you can have fun too.\n\n"
 "f - floor, p - player (repeat 'p' for layers)\n\n"
 "n - new shape, u - copy the 'player body' shape\n\n"
 "1-9 - rotational symmetries, 0 - toggle axial symmetry\n\n"
 "point with mouse and: a - add point, m - move nearest point, d - delete nearest point, c - nearest point again, b - add after nearest\n\n"
 "s - save in C++ format (but cannot be loaded yet without editing source)\n\n"
 "z - zoom, o - Poincaré model\n",

 "Bu modda, kendi karakterini ve zemini çizebilirsin. "
 "Aslında geliştirme amaçları için vri ama eğlence için de kullanabilirsin.\n\n"
 "f - zemin, p - oyuncu (katman eklemek için 'p'ye tekrar bas)\n\n"
 "n - yeni şekil, u - oyuncu şeklini kopyala\n\n"
 "1-9 - döngüsel simetriler, 0 - eksensel simetriyi aç/kapa\n\n"
 "fareyle göster ve: a - nokta ekle, m - en yakındaki noktaya git, d - en yakındaki noktayı sil, c - tekrar en yakın nokta, b - en yakından sonraya ekle\n\n"
 "s - C++ formatında sakla (ancak kaynağı düzenlemeden yüklenemez)\n\n"
 "z - yakınlaş, o - Poincaré modeli\n")

S(
 "These huge monsters normally live below the sand, but your movements have "
 "disturbed them. They are too big to be slain with your "
 "weapons, but you can defeat them by making them unable to move. "
 "This also produces some Spice. They move two times slower than you.",

 "Normalde bu canavarlar yer altında yaşarlar ama hareketlerin onları rahatsız etti. "
 "Bıçağınla kesilmek için fazla iriler, ama onları hareket edemez hale getirerek yenebilirsin. "
 "Bu biraz Baharat da üretir. Senden iki kat yavaş hareket ederler.")

S("The tentacles of Cthulhu are like sandworms, but longer. "
 "They also withdraw one cell at a time, instead of exploding instantly.",
 "Cthulhu'nun dokunaçları kumkurtları gibidir, ama daha uzundur. Ve birden patlamak yerine her seferinde bir hücregeri çekilirler.")

S(
 "A huge plant growing in the Jungle. Each Ivy has many branches, "
 "and one branch grows per each of your moves. Branches grow in a clockwise "
 "order. The root itself is vulnerable.",
 "Vahşi Ormanda büyüyen devasa bir bitki. Her sarmaşığın bir sürü dalı vardır ve senin her hareketinle bir dal büyür. Dallar saatyönü sırasında büyür. Kökün kendisi savunmasızdır. \n")

S("The Alchemists produce magical potions from pools of blue and red slime. You "
 "can go through these pools, but you cannot move from a blue pool to a red "
 "pool, or vice versa. Pools containing items count as colorless, and "
 "they change color to the PC's previous color when the item is picked up. "
 "Slime beasts also have to keep to their own color, "
 "but when they are killed, they explode, destroying items and changing "
 "the color of the slime and slime beasts around them.",
 "Simyacılar mavi ve kırmızı balçık havuzlarından sihirli iksirler üretirler. "
 "Bu havuzlardan geçebilirsin, ama kırmızı bir havuzdan mavi bir havuza veya tam tersine geçemezsin. "
 "Balçık canavarları kendi renklerinde durmak zorundadır, "
 "Ama öldüklerinde patlarlar ve etrafındaki eşyaları yok eder, etraflarındaki balçığın ve canavarların rengini değiştirirler. \n")

S(
 "These creatures are slow, but very powerful... more powerful than you. "
 "You need some more experience in demon fighting before you will be able to defeat them. "
 "Even then, you will be able to slay this one, but more powerful demons will come...\n\n"
 "Each 10 lesser demons you kill, you become powerful enough to kill all the greater "
 "demons on the screen, effectively turning them into lesser demons.",

 "Bu yaratıklar yavaştır ama çok güçlüdür. Senden bile. "
 "Bunları yenebilmek için öncesinde şeytanlarla savaşma konusunda tecrübeli olman gerekir. "
 "O zaman bile, bunu yenebilirsin, ama daha güçlü şeytanlar gelecektir...\n\n"
 "Öldürdüğün her 10 küçük şeytan için, ekrandaki bütün Büyük Şeytanları -sanki onlar da küçükmüş gibi- öldürebilirsin.")

S("These creatures are slow, but they often appear in large numbers.",
  "Bu yaratıklar yavaştır ama genellikle sürü halinde gezerler.")

S("A big monster from the Living Caves. A dead Troll will be reunited "
 "with the rocks, causing some walls to grow around its body.",
 "Yaşayan Mağaralardan büyük bir canavar. Ölü bir Trol etrafında yükselen duvarlarla kayalarla yeniden bütünleşir. ")

S("Huge, impassable walls which separate various lands.",
  "Farklı diyarları birbirinden ayıran çok yüksek, aşılamaz duvarlar.")

S(
 "This cave contains walls which are somehow living. After each turn, each cell "
 "counts the number of living wall and living floor cells around it, and if it is "
 "currently of a different type than the majority of cells around it, it switches. "
 "Items count as three floor cells, and dead Trolls count as five wall cells. "
 "Some foreign monsters also count as floor or wall cells.\n",
 "Bu mağara nasılsa yaşayan duvarlarla kaplıdır. Her tur her hücre çevresindeki yaşayan zemin ve yaşayan duvar hücrelerini sayar ve eğer çevresindeki çoğunluktan farklı bir türdeyse çoğunluğa dönüşür. "
 "Eşyalar üç zemin hücresi, ölü Troller beş duvar hücresi olarak sayılır.\n")

S(
 "This forest is quite dry. Beware the bushfires!\n"
 "Trees catch fire on the next turn. The temperature of the grass cells "
 "rises once per turn for each fire nearby, and becomes fire itself "
 "when its temperature has risen 10 times.\n"
 "You can also chop down the trees. Big trees take two turns to chop down.",
 "Bu orman epey kuru. Çalı yangınlarına dikkat et!\n"
 "Ağaçlar her tur ateşe yakalanır. Çimen hücrelerinin ısısı her tur yakındaki ateşle bir artar ve sonra ısısı 10 kez yükselirse, kendisi ateş olur.\n "
 "Ağaçları kesebilirsin. Büyük ağaçları kesmesi 2 tur alır.\n ")

S("A big and quite intelligent monster living in the Icy Land.",
  "Buz Diyarlarında yaşayan büyük ve epey zeki bir canavar.")

S(
 "A nasty predator from the Icy Land. Contrary to other monsters, "
 "it tracks its prey by their heat.",
 "Buz Diyarlarında yaşayan hınzır bir yırtıcı. Diğer canavarların aksine, avını ısısıyla takip ediyor.")

S("Rangers take care of the magic mirrors in the Land of Mirrors. "
 "They know that rogues like to break these mirrors... so "
 "they will attack you!",
 "Seyyahların aynalarını kıracağını bildiklerinden sana saldıracaklar!")

// TODO update translation
S("A nasty creature that lives in caves. They don't like you for some reason.",
 "Yaşayan Mağaralarda yaşayan iğrenç bir yaratık. Nedense seni hiç sevmiyor.")

S("A tribe of men native to the Desert. They have even tamed the huge Sandworms, who won't attack them.",
  "Çölde yaşayan bir insan jabilesi. Büyük Kumkurtlarını evcilleştirip kendilerine saldırmamasını sağladılar.")

S("This giant ape thinks that you are an enemy.", "Bu devasa maymun senin bir düşman olduğunu düşünüyor.")

S("A magical being which copies your movements.", "Hareketlerini taklit eden bir büyülü varlık.")

S("A magical being which copies your movements. "
 "You feel that it would be much more useful in an Euclidean space.",
 "Hareketlerini taklit eden bir büyülü varlık. Bunların Öklid uzayında daha işe yarayacağını düşünmeden edemiyorsun .")

S("You can summon these friendly constructs with a magical process.",
  "Bu dost mekanizmaları büyüsel bir işlemle uyandırabilirsin.")

S("A majestic bird, who is able to fly very fast.",
  "Çok hızlı uçabilen görkemli bir kuş.")

S("A monster who is able to live inside the living cave wall.",
  "Yaşayan mağara duvarlarında yaşayabilen bir canavar.")

S("A typical Graveyard monster.", "Mezarlıkta sık rastlanan bir canavar.")

S("A typical monster from the Graveyard, who moves through walls.\n\n"
  "There are also wandering Ghosts. They will appear "
  "if you do not explore any new places for a long time (about 100 turns). "
  "They can appear anywhere in the game.",
  "Mezarlıkta sık rastlanan bir canavar. Duvarlardan geçebilir.\n\n"
  "Ayrıca amaçsızca gezinen hayaletler var. Uzunca bir süre (100 tur kadar) yeni diyarlar keşfetmediğinde karşına çıkarlar. Oyundaki herhangi bir yerde karşına çıkabilirler."
  )

S("Necromancers can raise ghosts and zombies from fresh graves.",
  "Ölüçağıranlar mezarlardan hayaletler ve hortlaklar çağırabilirler.")

S("A creepy monster who follows you everywhere in the Graveyard and the Cursed Canyon.",
  "Seni Mezarlık boyunca takip eden ürpertici bir canavar.") //TODO UPDATE

S("People worshipping Cthulhu. They are very dangerous.",
  "Cthulhu'ya tapan insanlar. Çok tehlikeliler.")

S("People worshipping Cthulhu. This one is especially dangerous, "
 "as he is armed with a weapon which launches fire from afar.",
 "Cthulhu'ya tapan insanlar. Bu özellikle tehlikeli ve uzaktan ateş atabilmesini sağlayan bir silahı var.")

S("This dangerous predator has killed many people, and has been sent to Cocytus.",
  "Bu tehlikeli yırtıcı çok kişiyi öldürdü ve Kokitos'a gönderildi.")

S("This white dog is able to run all the time. It is the only creature "
 "able to survive and breed in the Land of Eternal Motion.",
 "Bu beyaz köpek hiç durmadan koşabilir. Sonsuz hareket diyarında yaşayabilen ve çoğalabilen tek canlıdır.")

S("Demons of Hell do not drown when they fall into the lake in Cocytus. "
 "They turn into demonic sharks, enveloped in a cloud of steam.",
 "Cehennem Şeytanları Kokitos'ta göle düştüklerinde boğulmazlar."
 "Bir buhar bulutuyla kaplı şeytanî köpekbalıklarına dönüşürler.")

S("These fairies would rather burn the forest, than let you get some Fern Flowers. "
 "The forest is infinite, after all...\n\n"
 "Fire Fairies transform into fires when they die.",
 "Bu periler ormanı yakma pahasına, kimsenin Eğreltiotu Çiçeklerine dokunmasına izin vermezler."
 "Sonuçta orman sonsuza kadar uzanıyor...\n\n"
 "Ateş perileri öldüklerinde ateşe dönüşürler.")

S("These warriors of the Forest wield exotic weapons called hedgehog blades. "
 "These blades protect them from a frontal attack, but they still can be 'stabbed' "
 "easily by moving from one place next to them to another.",
 "Ormandaki bu savaşçılar, adına kirpi bıçağı denen ilginç bıçaklar taşıyorlar. Bu bıçaklar onları önden gelen saldırılardan korur, ama hâlâ yanlarından geçerek öldürülebilirler.")

S("This being radiates an aura of wisdom. "
 "It is made of a beautiful crystal, you would love to take it home. "
 "But how is it going to defend itself? Better not to think of it, "
 "thinking causes your brain to go hot...\n\n"
 "Crystal Sages melt at -30 °C, and they can raise the temperature around you from afar.",
 "Muhteşem bir kristalden yapılmış, eve götürmeyi çok isterdin."
 "Ama kendini nasıl savunacak? Düşünmesen daha iyi, "
 "sadece düşünmek bile beynini zorluyor. ...\n\n"
 "Kristal Pirleri -30 °C'de erir ve etrfındaki ısıyı uzaktan artırabilir.")

S("Cold white gems, found in the Icy Land.", "Buz Diyarlarında bulunan soğuk beyaz mücevherler.")

S("An expensive metal from the Living Caves. For some reason "
 "gold prevents the living walls from growing close to it.",
 "Yaşayan Mağaralardan pahalı br metal. Anlaşılamayan bir sebeple altın yaşayan duvarları kendine yaklaştırmıyor.")

S("A rare and expensive substance found in the Desert. "
 "It is believed to extend life and raise special psychic powers.",
 "Çölde bulunan ender ve pahalı bir katkı maddesi. Yaşamı uzattığına ve bazı özel psişik güçleri açığa çıkardığına inanılıyor.")

S("A beautiful gem from the Jungle.", "Vahşi Ormandan elde edilmiş bir mücevher.")

S(
 "A wonderful beverage, apparently obtained by mixing red and blue slime. You definitely feel more "
 "healthy after drinking it, but you still feel that one hit of a monster is enough to kill you.",
 "Şahane bir içki, görünen o ki kırmızı ve mavi balçığın karıştırılmasıyla elde edilmiş. İçince daha sağlıklı hissediyorsun ama bir canavarın tek vuruşunun seni öldüreceğine de eminsin.")

S("A piece of a magic mirror, or a mirage cloud, that can be used for magical purposes. Only mirrors and clouds "
 "in the Land of Mirrors leave these.",
 "Sihirli aynanın veya yansı bulutunun bir parçası. Sihirli amaçlar için kullanılabilir. Sadece aynalar ve bulutlardan düşer.")

S("These sinister totems contain valuable gems.",
  "Bu tekinsiz totemler değerli mücevherler içeriyor.")

S("These star-shaped flowers native to Hell are a valuable alchemical component.",
  "Cehennemde yetişen bu yıldız şekilli çiçekler değerli bir simya bileşeni.")

S("This statue is made of materials which cannot be found in your world.",
  "Bu heykel, senin geldiğin dünyada bulunamayacak maddelerden yapılmış.")

S("One of few things that does not cause the floor in the Land of Eternal Motion to collapse. Obviously they are quite valuable.",
  "Hareketler Diyarında yerlerin çökmemesini sağlayan ender şeylerden biri. Bunlar, tabi ki epey değerli.")

S("Cold blue gems, found in the Cocytus.", "Mavi soğuk mücevherler sadece Kokitos'ta bulunabilir.")

S("These bright yellow gems can be found only by those who have mastered the Crossroads.",
  "Bu sarı parlak mücevherler Arayollarda yeterince deneyim kazananlar tarafından bulunabilir.")

S("That's all you need to unlock the Orb of Yendor! Well... as long as you are able to return to the Orb that this key unlocks...\n\n"
 "Each key unlocks only the Orb of Yendor which led you to it.",
 "Yendorun Küresinin kilidini açmak için ihtiyacınız olan her şeyi tamamladın. Tabi... Önce Küreyr dönmen gerekiyor...\n"
 "Her anahtar seni ona yönlendiren yendorun küresini açacaktır.")

S("These orbs can be found in the Graveyard. You think that they were once powerful magical orbs, but by now, their "
 "power is long gone. No way to use them, you could as well simply drop them...\n\n",
 "Bu küreler Mezarlıkta bulunabilir. Eskiden kudretli sihrili kürelerdi, ama şimdi güçleri bitti. Onları kullanmanın bir yolu yok, bırakın gitsin...\n\n")

S(
 "This wonderful Orb can only be collected by those who have truly mastered this hyperbolic universe, "
 "as you need the right key to unlock it. Luckily, your psychic abilities will let you know "
 "where the key is after you touch the Orb.",
 "Bu harika Küre kilidini açmak için doğru anahtarı gerektirdiğinden, sadece bu hiperbolik evrende tamamen ustalaşmış kişilerce toplanabilir."
 "Çok şükür, küreye dokununca psişik yeteneklerin sana anahtarın nerede olduğunu söyler.")

S(
  "This orb can be used to invoke the lightning spell, which causes lightning bolts to shoot from you in all directions.",
  "Bu küre şimşek büyüsünü kullanmaya yarar, senden her yöne doğru kıvılcımlar saçılır.")

S("This orb can be used to invoke a flash spell, which destroys almost everything in radius of 2.",
  "Bu küre ışık büyüsünü kullanmaya yarar. Işık büyüsü, 2 hücre uzaklıktaki her şeyi yok eder.")

S("This orb can be used to invoke a wall of ice. It also protects you from fires.",
  "Bu küre bir buz duvarı oluşturmaya yarar. Aynı zamanda seni ateşten korur")

S("This orb can be used to move faster for some time.",
  "Bu küre bir süreliğine daha hızlı hareket etmeye yarar.")

S("This orb can be used to summon friendly golems. It is used instantly when you pick it up.",
  "Bu küre size dost golemler çağırmak için kullanılır. Onu eline aldığında anında kullanılır.")

S("This orb can protect you from damage.", "Bu küre seni hasardan korur.")

S("This orb lets you go through living walls. It also has powers in some of the other lands.",
  "Bu küre Yaşayan Duvarların içinden geçebilmenizi sağlar.")//Sadece Yaşayan Mağaralarda işe yarar.")

S("This orb lets you instantly move to another location on the map. Just click a location which "
 "is not next to you to teleport there. ",
   "Bu küre haritadaki balşka bir noktaya anında ışınlanmanızı sağlayacak. Işınlanmak için sadece yanında olmayan bir yere tıkla.")

S("This orb lets you instantly move to a safe faraway location. Knowing the nature of this strange world, you doubt "
 "that you will ever find the way back...\n\n"
 "Your game will be saved if you quit the game while the Orb of Safety is still powered.\n\n"
 "Technical note: as it is virtually impossible to return, this Orb recycles memory used for the world so far (even if you do not use it to save the game). ",
 "Bu küre seni güvenli bir uzak yere ışınlar. Bu dünyanın garip yapısını düşününce "
 "geri dönüp dönemeyeceğin belli değil...\n\n"
 "Eğer Güvenlik Küresi hâlâ açıkken oyundan çıkarsan oyunun kaydedilecek.\n\n"
 "Teknik not: geri dönmek aslında tamamen imkânsız olduğundan, bu Küre sadece şimdiye kadar bu dünya için kullanılan hafızayı kullanır. (onu ounu kaydetmek için kullanmasanız da.) ")

S("This orb allows attacking Hedgehog Warriors directly, as well as stabbing other monsters.\n",
  "Bu küre Kirpi Savaşçılara doğrudan saldırmaya ve diğer canavarları bıçaklamaya izin verir.\n")

S("This flower brings fortune to the person who finds it.\n",
  "Bu çiçek kendisini bulana şans getirir.\n")

S("Ice Walls melt after some time has passed.", "Buz Duvarları biraz zaman geçince erirler.")

S("A natural terrain feature of the Desert.", "Çölün içinde doğal bir kum oluşumu.")

S("You can go inside the Magic Mirror, and produce some mirror images to help you.",
  "Sihirli aynanın içine girerek sana yardım etmesi için bazı yansımalar üretebilirsin.")

S(
 "Tiny droplets of magical water. You see images of yourself inside them. "
 "Go inside the cloud, to make these images help you.",
 "Ufak sihirli su damlaları. Kendi görüntünü içlerinde görüyorsun. "
 "Bu görüntülerin sana yardım etmesi için bulutun içine gir. ")

S("A device that attracts sandworms and other enemies. You need to activate it.",
  "Kumkurtlarını ve diğer düşmanları çağıracak bir aygıt. Sadece etkinleştirmen gerekiyor.")

S("A heap of wood that can be used to start a fire. Everything is already here, you just need to touch it to fire it.",
  "Ateş yakmaya uygun bir yığın odun. Her şey zaten burada, ateş için sadece dokunman yetecek.")

S("An ancient grave.", "Antik bir mezar.")

S("A fresh grave. Necromancers like those.", "Taze bir mezar. Ölüçağıranlar bunu sever.")

S("A piece of architecture typical to R'Lyeh.", "R'Lyeh'e özgü bir mimari eser.")

S("An impassable lake in Cocytus.", "Kokitos'ta, üzerinden geçilemeyen bir göl.")

S("You can walk on it... but beware.", "Üzerinde yürüyebilirsin. Ama dikkatli ol!")

S("It was a floor... until something walked on it.", "Burası bir zemin parçasıydı...ta ki bir şey üzerinden geçene kadar.")

S(
 "This land is a quick gateway to other lands. It is very easy to find other lands "
 "from the Crossroads. Which means that you find monsters from most other lands here!\n\n"
 "As long as you have found enough treasure in their native lands, you can "
 "find magical items in the Crossroads. Mirror Land brings mirrors and clouds, "
 "and other land types bring magical orbs.\n\n"
 "A special treasure, Hyperstone, can be found on the Crossroads, but only "
 "after you have found 10 of every other treasure.",
 "Bu diyar diğer diyarlara kolay geçiş için var. Arayollardan başka diyarları bulması çok kolay. "
 "Bu demektir ki, burada başka diyarlardan canavarlar bulman çok olası!\n\n"
 "Eğer hazineleri kendi yerlerinde yeterince topladıysan, Arayollarda sihirli eşyalar bulabilirsin. "
 "Ayanalar Diyarından yansımalar ve bulutlar, diğer diyarlardan sihirli küreler gelebilir.\n\n"
 "Özel bir hazine, Aşkıntaş, sadece Arayollarda bulnabilir, ama öncesinde diğer her hazine çeşidinden 10'ar tane bulman gerekiyor.")

S("A hot land, full of sand dunes, mysterious Spice, and huge and dangerous sand worms.",
  "Kum tepeleri, gizemli Baharat ve devasa Kumkurtlarıyla dolu sıcak bir diyar.")

S(
 "A very cold land, full of ice walls. Your mere presence will cause these ice walls to "
 "melt, even if you don't want it.",
 "Buz duvarlarıyla dolu çok soğuk bir diyar. Sen istemesen de sadece varlığın bile duvarların erimesine sebep oluyor.")

S("A land filled with huge ivy plants and dangerous animals.",
  "Sarmaşık bitkileri ve tehlikeli hayvanlarla dolu bir diyar.")

S("A strange land which contains mirrors and mirages, protected by Mirror Rangers.",
  "Aynalar ve yansımalarla dolu garip bir diyar, ayna korucuları tarafından korunuyor.")

S("All the monsters you kill are carried to this strange land, and buried. "
 "Careless Rogues are also carried here...",
 "Öldürdüğünüz bütün canavarlar buraya taşındı ve gömüldü. Dikkatsiz Seyyahlar da buraya taşındı...")

S("An ancient sunken city which can be reached only when the stars are right.\n\n"
  "You can find Temples of Cthulhu in R'Lyeh once you collect five Statues of Cthulhu.",
  "Sadece yıldızlar burayı işaret ettiğinde ulaşılabilecek batık bir antik şehir.\n\n"
  "Cthulhu'nun tapınaklarını 5 Cthulhu heykeli topladıktan sonra bulabilirsin.")

S("A land filled with demons and molten sulphur. Abandon all hope ye who enter here!",
  "Şeytanlarla ve erimiş sülfürle dolu bir diyar. Buraya giriyorsan tüm ümitlerini terket!")

S("This frozen lake is a hellish version of the Icy Land. Now, your body heat melts the floor, not the walls.",
  "Bu donmuş göl, Buz Diyarlarının korkunç bir versiyonu gibi. Şimdi, vücut ısın duvarları değil, yeri eritiyor.")

S("A land where you cannot stop, because every piece of floor is extremely unstable. Only monsters who "
 "can run forever are able to survive there, and only phoenix feathers are so light that they do not disturb "
 "the floor.\n",
 "Duramayacağınız bir diyar...Çünkü zeminin her noktası oldukça kırılgan. Sadece sonsuza kadar koşabilen canavarlar"
 " burada yaşayabilirler ve anka telekleri öyle hafiftir ki, zemine zarar vermezler.")

S("Affects looks and grammar", "Görüntüyü ve grameri etkiler")

S("first joystick: movement threshold", "birinci oyun kolu: hareket eşiği")
S("first joystick: execute movement threshold", "birinci oyun kolu: hareket algılama eşiği")
S("second joystick: pan threshold", "ikinci oyun kolu: gezdirme hızı")
S("second joystick: panning speed", "ikinci oyun kolu: gezdirme hızı")
S("%The1 is frozen!", "%1 dondu!")
S("%The1 burns!", "%1 yandı!")
S("message flash time", "mesaj gösterme süresi")

S("Euclidean mode", "Öklid modu")
S("Return to the hyperbolic world", "Hiperbolik Dünyaya geri dön")
S("Choose from the lands visited this game.", "Oyunda eriştiğin diyarlardan birini seç.")
S("Scores and achievements are not", "Başarımlar ve puanlar Öklid")
S("saved in the Euclidean mode!", "modunda kaydedilmeyecek!")

S("Your total treasure has been recorded in the Google Leaderboards.", "Toplam hazinen Google Listelerine kaydedildi.")
S("You have improved your total high score on Google. Congratulations!", "Google'daki toplam yüksek puanını artırdın. Tebrikler!")
S("This has been recorded in the Google Leaderboards.", "Bu Google Listelerine kaydedildi.")
S("You have improved your '%1' high score on Google!", "Google'daki '%P1'puanını artırdın!")

S("MOVE", "OYNAT")
S("BACK", "GERİ")
//S("DRAG", "SÜRÜKLE")
S("DRAG", "SRKLE")
S("INFO", "BİLGİ")
S("MENU", "MENÜ")
S("QUEST", "GÖREV")
S("HELP", "YARDIM")
S("NEW", "YENİ")
S("PLAY", "OYNA")
S("SHARE", "PAYLAŞ")
S("HyperRogue for Android", "Android için HyperRogue")
S("Cheats: ", "Hileler: ")
S("Score: ", "Puan: ")
S("Kills: ", "Leşler: ")
S("Retrieving scores from Google Leaderboards...", "Google listelerindeki puanlar yükleniyor...")
S("Scores retrieved.", "Puanlar yüklendi.")

S("Ever wondered how some boardgame would look on the hyperbolic plane? "
 "I wondered about Go, so I have created this feature. Now you can try yourself!\n"
 "Enter = pick up an item (and score), space = clear an item\n"
 "Other keys place orbs and terrain features of various kinds\n"
 "In the periodic editor, press 0-4 to switch walls in different ways\n",
 "Hiç bir oyunun hiperbolik düzlemde nasıl görüneceğini merak ettin mi? "
 "Ben Go hakkında merak ettim ve bu özelliği geliştirdim. Sen de deneyebilirsin!\n"
 "Enter = bir itemi al (ve puan kazan), space = bir itemi temizle\n"
 "Diğer tuşlar küreler ve çeşitli arazi özellikleri eklemek için.\n")

S("","") N("",GEN_N,"","","","")

S("Periodic Editor", "Periyodik Editör")
// also translate this line:
// "In the periodic editor, press 0-4 to switch walls in different ways\n",
// "Periyodik editörde, duvarları farklı şekillerde seçmek için 0-4'e basın.\n"

S("Collect %1 $$$ to access even more lands", "Daha da fazla diyara ulaşmak için %1 $$$ toplayın.")

// Emerald Mine
// ------------

N("Emerald Mine", GEN_F, "Zümrüt Madeni", "Zümrüt Madenleri", "Zümrüt Madenini", "Zümrüt Madeninde")
N("Pikeman", GEN_M, "Mızraklı", "Mızraklılar", "Mızraklıyı", "Mızraklıyla")
N("Flail Guard", GEN_M, "Topuz Muhafızı", "Topuz Muhafızları", "Topuz Muhafızını", "Topuz Muhafazıyla")
N("Miner", GEN_M, "Madenci", "Madenciler", "Madenciyi", "Madenciyle")
N("Emerald", GEN_O, "Zümrüt", "Zümrütler", "Zümrütü", "Zümrütle")

Orb("the Mind", "Psychiki")

S(
     "Evil people are mining for emeralds in this living cave. "
     "It does not grow naturally, but it is dug out in a regular "
     "pattern, which is optimal according to the evil engineers.",
     "Kötü insanlar bu mağarada zümrüt çıkarıyor. Doğal yollarla çıkmıyor, şeytani mühendislerin işine gelecek şekilde düzenli bir şemayla çıkarılıyor.")

S(
    "Miners have special tools for dealing with the Living Cave. "
    "When they die, these tools activate, destroying the living cave "
    "around them.",
    "Madenciler Yaşayan Mağarayla baş etmek için özel gereçlere sahipler. Öldüklerinde, bu gereçler aktifleşiyor ve etraflarındaki Yaşayan Mağarayı yok ediyor.")

S(
    "When Pikemen move, they attack all cells which are now adjacent to them. "
    "Luckily, they can be killed in the same way.\n\n"
    "They never move if this would attack their friends.",
    "Mızraklılar hareket ettiğinde değdikleri tüm hücrelere saldırırlar. Çok şükür aynı şekilde öldürülebiliyorlar da. Arkadaşlarına hasar vereceklerse hareket etmiyorlar.")

S(
    "This guard of the Emerald Mine is wielding a huge flail. "
    "You cannot attack him directly, as the flail would still hit you then. "
    "Luckily, you have learned a trick: if you step away from him, "
    "he will hit himself with the flail!",

    "Zümrüt Madeninin bu muhafızı kocaman bır topuz tutuyor. Ona doğrudan saldıramazsın, çünkü topuz sana yine de vurur. Çok şükür bir hile öğrendin: Eğer geriye doğru bir adım atarsan, muhafız topuzuyla kendisine vuracak!")

S("A precious green gem from the Emerald Mines.", "Zümrüt Madenlerinden eğerli yeşil bir mücevher.")

S("%The1 pierces %the2!", "%1 %a2 delip geçiyor!")

S("Make him hit himself by walking away from him.",
  "Ondan uzaklaşarak kendisine vurmasını sağla.")

S("This orb allows you to instantly kill a non-adjacent enemy by clicking it. "
    "Each use drains 30 charges.",
  "Bu küre yakında olmayan herhangi bir düşmana tıklayarak onu öldürebilmene izin verir. Her kullanım 30 şarj götürür.")

S("%The1 is immune to mental blasts!", "%1 zihin patlamasından etkilenmez!")
S("You kill %the1 with a mental blast!", "%a2 zihin patlamasıyla öldürdün!")

// Vineyard
// --------

N("Vineyard", GEN_F, "Şaraplık", "Şaraplıklar", "Şaraplığı", "Şaraplıkta")
N("Vine Beast", GEN_M, "Şarap Canavarı", "Şarap Canavarları", "Şarap Canavarını", "Şarap Canavarıyla")
N("Vine Spirit", GEN_M, "Şarap Özü", "Şarap Özleri", "Şarap Özünü", "Şarap Özüyle")
N("vine", GEN_F, "şarap", "şaraplar", "şarabı", "şarapla")
N("partial fire", GEN_M, "kısmî ateş", "kısmî ateşler", "kısmî ateşi", "kısmî ateşle")
N("Wine", GEN_N, "Şarap", "Şaraplar", "Şarabı", "Şarapla")

S(  "This cell is partially on fire.", "Bu hücre kısmen alevler içinde.")

S(
  "The Vineyard is filled with vines. A very dense pattern of straight lines here...\n\n"
  "Vine Beasts and Vine Spirits change vine cells to grass, and vice versa.",
  "Şaraplık şaraplarla dolu. Burada çok sık düz çizgiler var ...\n\n"
  "şŞarap Canavarları ve Şarap Özleri şarap hücrelerini çimene ve tam tersine çevirir.")

S("A vine is growing here... but only on a half of the cell. How is that even possible?!"
  "Most monsters cannot move from this cell to the cell containing the other half. "
  "Vine spirits can move only to the adjacent cells which are also adjacent to the "
  "other half.",
  "Burada şarap oluşuyor... ama sadece hücrenin yarısında. Bu nasıl mümkün olabilir?! Çoğu canavar bu hücreden diğer yarıyı içeren hücreye hareket edemez. Şarap özleri sadece diğer yarıya da bitişik olan hücrelere gidebilir.")

S(
    "A beast made of vines!\n\n"
    "Vine Beasts turn into vines when they die.",
    "Şaraptan yaratılmış bir canavar!\n\n"
    "Şarap Canavarı öldüğünde şaraba dönüşür.")

S(  "A spirit living in the vines!\n\n"
    "Vine Spirits destroy the vines when they die.",
    "Şarabın içinde yaşayan bir ruh!\n\n"
    "Şarap ruhları öldüklerinde etraflarındaki şarabı yok eder.")

S("Wine grown under hyperbolic sun would be extremely prized in your home location.",
  "Hiperbolik güneşin altında oluşan şarap geldiğin yerde epey değerli olsa gerek.")

S("This orb allows one to pass through all kinds of walls and chasms.",
  "Bu küre her türlü duvarların ve çatlakların içinden geçmene izin verir.")

S("You cannot attack through the Vine!",
  "Şarabın içinden saldıramazsın!")

Orb("Aether", "Eter")

// Dead Caves
// ----------

N("Dead Cave", GEN_F, "Ölü Mağara", "Ölü Mağaralar", "Ölü Mağarayı", "Ölü Mağarada")
N("Dark Troll", GEN_M, "Kara Trol", "Kara Troller", "Kara Trolü", "Kara Trolle")
N("Earth Elemental", GEN_M, "Toprakadam", "Toprakadamlar", "Toprakadamı", "Toprakadamla")
N("dead wall", GEN_F, "ölü duvar", "ölü duvarlar", "ölü duvarı", "ölü duvarda")
N("dead floor", GEN_F, "ölü zemin", "ölü zeminler", "ölü zemini", "ölü zeminde")
N("rubble", GEN_O, "gruz", "gruzy", "gruz", "gruzem")
N("Silver", GEN_N, "Gümüş", "Gümüşler", "Gümüşü", "Gümüşle")

S("A precious metal from the Dead Caves.", "Ölü mağaralardan çıkan değerli bir metal.")

S(  "A Troll without the power of Life.", "Hayat gücünden mahrum bir trol.")

S(
    "A rare unliving construct from the Dead Caves. "
    "It instantly destroys cave walls next to its path, and also leaves "
    "an impassable wall behind it. You suppose that this impassable wall helps it to "
    "escape from some threats. You hope you won't meet these threats...",

    "Ölü Mağaralardan cansız bir mekanizma. Yoluna çıkan tüm mağara duvarlarını yıkar ve arkasında geçilemeyen bir duvar bırakır."
    "Bu duvarları birtakım tehditlerden kullanabileceğini düşünüyorsun. Aynı zamanda bu tehditlerle hiç karşılaşmayacağını da umuyorsun..")

S("%The1 punches %the2!", "%1 %a2 yumrukladı!")
S("%The1 is destroyed by the forces of Life!", "Yaşam güçleri %a1 yok etti!")
S(  "Somehow, this cave has not received the spark of Life yet.",
    "Nasılsa bu mağaraya yaşamın ışığı hiç uğramamış.")

// Hive
// ----

N("Hive", GEN_N, "Kovan", "Kovanlar", "Kovanı", "Kovanda")
N("Red Hyperbug", GEN_M, "Kırmızı Aşkınböcek", "Kırmızı Aşkınböcekler", "Kırmızı Aşkınböceği", "Kırmızı Aşkınböcekle")
N("Green Hyperbug", GEN_M, "Yeşil Aşkınböcek", "Yeşil Aşkınböcekler", "Yeşil Aşkınböceği", "Yeşil Aşkınböcekle")
N("Blue Hyperbug", GEN_M, "Mavi Aşkınböcek", "Mavi Aşkınböcekler", "Mavi Aşkınböceği", "Mavi Aşkınböcekle")
N("Royal Jelly", GEN_N, "Müthiş Jöle", "Müthiş Jöleler", "Müthiş Jöleyi", "Müthiş Jöleyle")
N("weird rock", GEN_N, "garip kaya", "garip kayalar", "garip kayayı", "garip kayayla")

Orb("Invisibility", "Görünmezlik")

S("A weirdly colored rock. Hyperentomologists claim that the "
  "Hyperbug armies use these rocks to navigate back home after a victorious battle.",
  "Garip renkli bir kaya. Aşkınböcekbilimcilere göre aşkın böcek orduları bu kayaları zaferlerinden sonra evlerini bulmak için kullanıyorlar.")

S("%The1 fights with %the2!", "%1 %a2 savaşıyor!")

S("The Hive is filled with Hyperbugs. They are huge insects which look a bit like "
  "ants, a bit like bees, and a bit like roaches. "
  "They live in circular nests, and an army of Hyperbugs will attack any intruder, "
  "including you and enemy Hyperbugs. Will you manage to get to the "
  "heart of such a nest, and get the precious Royal Jelly?",
  "Kovan aşkın böceklerle dolu. Aşkınböcekler biraz arıya biraz karıncaya biraz da hamamböceğine benzeyen kocaman böcekler. Dairesel kovanlarda yaşıyorlar ve yaklaşan düşman aşkınböceklerine"
  "ve sana saldıracaklardır. Kovanın merkezine ulaşıp Müthiş Jöleyi ele geçirebilecek misin ?")

S("This is what Hyperbug Queens eat. Very tasty and healthy.",
  "Bu Aşkınböcek Kraliçelerinin yediği şey. Çok lezzetli ve sağlıklı.")

S("When you have this Orb, most monsters won't see you, unless "
    "you are standing still, attacking, or picking up items.",
  "Bu küren varsa çoğu canavar seni beklemediğin, saldırmadığın yahut yerden bir şey almadığın sürece görmez.")

Orb("Earth", "Toprak")

S("This orb lets you go through living walls. It also has powers in some of the other lands.",
  "Bu küre yaşayan duvarların içinden geçebilmeni sağlar. Bazı başka diyarlarda da başka güçleri olabilir.")

// Land of Power
// -------------

N("Land of Power", GEN_F, "Güç Diyarı", "Güç Diyarları", "Güç Diyarını", "Güç Diyarında")
N("Witch Apprentice", GEN_F, "Cadı Kalfası", "Cadı Kalfaları", "Cadı Kalfasını", "Cadı Kalfasıyla")
N("Speed Witch", GEN_F, "Hız Cadısı", "Hız Cadıları", "Hız Cadısını", "Hız Cadısıyla")
N("Flash Witch", GEN_F, "Işık Cadısı", "Işık Cadıları", "Işık Cadısını", "Işık Cadısıyla")
N("Fire Witch", GEN_F, "Ateş Cadısı", "Ateş Cadıları", "Ateş Cadısını", "Ateş Cadısıyla")
N("Aether Witch", GEN_F, "Eter Cadısı", "Eter Cadıları", "Eter Cadısını", "Eter Cadısıyla")
N("Winter Witch", GEN_F, "Kış Cadısı", "Kış Cadıları", "Kış Cadısını", "Kış Cadısıyla")
N("Evil Golem", GEN_M, "Şeytani Golem", "Şeytani Golemler", "Şeytani Golemi", "Şeytani Golemle")
N("Powerstone", GEN_M, "Güç Taşı", "Güç Taşları", "Güç Taşını", "Güç Taşıyla")
N("crystal cabinet", GEN_F, "Kristal Kabin", "Kristal Kabinler", "Kristal Kabini", "Kristal Kabinle")

S("When you have this Orb, you will leave a trail of fire behind you.",
  "Bu Küreye sahip olduğunda arkanda bir ateşten yol bırakırsın.")

S(
    "A Witch without any special powers. But watch out! She will "
    "pick up any basic Orbs on her path, and use their powers.",
    "Herhangi bir gücü olamyan bir Cadı. Ama dikkat! Yolunun üzerindeki herhangi bir Küreyi alıp güçlerini kullanabilir.")

S(  "A Witch with a Speed spell. She moves twice as fast as you. Unless you "
    "have an Orb of Speed too, of course!",
    "Hız büyüsü olan bir Cadı. Senden iki kat hızlı hareket eder. Tabi senin de bir Hız Küren yoksa!")

S(  "A Witch with a Fire spell. She will leave a trail of fire behind her.",
    "Ateş büyüsü olan bir Cadı. Arkasında ateşten bir yol bırakır.")

S(  "A Witch with a Winter spell. She is able to move through fire.",
    "Kış büyüsü olan bir cadı. Ateşin içinde yürüyebilir.")

S(  "A Witch with an Aether spell. She is able to move through fire and walls.",
    "Eter büyüsü olan bir cadı. Duvarların ve ateşin içinden geçebilir.")

S(  "Somebody has summoned these evil constructs with a magical process.",
    "Birisi büyüyle işleyen bu mekanizmaları harekete geçirmiş.")

S(  "The Land of Power is filled with everburning fire, magical Orbs, and guarded by "
    "witches and golems. There are basic orbs lying everywhere, and more prized ones "
    "are kept in crystal cabinets.\n\n"
    "Witches are allowed to use all the powers of the "
    "basic orbs against intruders. These powers never expire, but a Witch "
    "can use only one power at a time (not counting Orbs of Life).\n\n"
    "Witches and Golems don't pursue you into other Lands. Also, most Orb powers "
    "are drained when you leave the Land of Power.",
    "Güç Diyarı sönmeyen ateşle, büyülü Kürelerle dolu ve cadılar ve golemler ile korunuyor. Her yerde temel Küreler var ve daha değerliler de kristal kabinlerde korunuyor. \n\n"
    "Cadılar bu kürelerin gücünü olası işgalcilere karşı kullanabilirler. Bu güçlerin süresi bitmez ama Yaşam Küresi hariç cadılar aynı anda sadece birini kullanabilir. \n\n"
    "Cadılar ve Golemler seni diğer diyarlara kadar takip etmezler. Ayrıca çoğu kürenin gücü Güç Diyarını terkettiğinde biter.")

S(
    "Witches use these crystal cabinets to protect Powerstones, as well as the more "
    "expensive Orbs. They are partially protected from thieves: they are too strong "
    "to be smashed by conventional attacks, and if you try to steal the item "
    "using an Orb of Aether, your Aether power will be completely drained.",
  "Bu kabinleri Cadılar Güçtaşlarını ve değerli Küreleri korumak için kullanıyorlar. Hırsızlara karşı kısmen korumalıdır, bildik saldırılarla kırılmak için fazlasıyla serttir ve eğer içindeki eşyayı Eter Küresi kullanarak çalmaya çalışırsan kürenin gücü bitecektir.")

S(
    "A Stone from the Land of Power. You are not sure what it is exactly, but "
    "as the Powerstones are kept in crystal cabinets, they are surely valuable.",
    "Güç Diyarından bir taş. Ne olduğuna tam olarak emin değilsin, ama bu taşlar kristal kabinlerde saklandığına göre çok değerli olmalılar.")

Orb("Fire", "Ateş")

// achievements
// ------------

// x "Head Witch", "Have 10 Orbs active at the same time."
// "Enemy Number One", "Have an army of 1000 hyperbugs pursue you."
// x "Lifebringer", "Brought Life into the Dead Caves."
// "Wall Gardener", "Make a living wall grow outside of a cavernous region."
// x "Master Swordsman", "Defeat a Hedgehog Warrior, a Pikeman, and a Flail Guard at the same time."
// x "Master of Melee", "Defeat five monsters in melee at the same time."

// for collection achievements:
// provide the required cases for descriptions:
// Spice, Royal Jelly, Silver, Powerstone, and Wine
// achievement names:
// Master of the Hive, Master of Power, Master of Vineyard, Master of Dead Caves, Master of the Mine
// "Hyperbug", "Hyperbug Warrior", "Hyperbug Queen",

// for the store description:

// (currently, five more lands are included!)

// lines forgotten previously

S("Your Aether power has expired! RUN!", "Eter gücünün süresi bitti! KAÇ!")

S("%The1 tricks %the2.", "%1 %a2 kandırdı.")
S("You trick %the1.", "%a1 kandırdın.")

S(  "A Witch with a Flash spell. Very dangerous!\n\nLuckily, she never uses the spell if it "
    "would kill her friends. She could destroy an Evil Golem, though.",
    "Işık büyüsü olan bir cadı. Çok tehlikeli!\n\n Çok şükür, büyüsünü büyüsü arkadaşlarını da öldürecekse hiç kullanmaz. Ama Şeytani Golemi de umursayacak değil tabi.")

S("Your Aether powers are drained by %the1!", "Güçlerin %1 tarafından tüketiliyor!")
S("As you leave, your powers are drained!", "Ayrılırken, tüm güçlerinin tükendiğini farkettin!")
S("%The1 picks up %the2!", "%1 %a2 kaldırdı!") // currently only Witches, so only female form

S("You can right click any element to get more information about it.\n\n",

  "Herhangi bir şeye sağ tıklayarak hakkında daha çok bilgiye ulaşabilirsin.\n\n")

// S("The Hyperbugs are fighting!", "Aşkın böcekler savaşıyor!")
S("The Hyperbugs are fighting!", "Aşkınböcekler savaşıyor!")

S("Dead floor, with some rubble.", "Ölü zemin, üstünde taş parçaları var.")
S("Cheat-changed the display.", "Cheat-changed the display.")

S("skin color", "deri rengi")
S("weapon color", "silah rengi")
S("hair color", "saç rengi")
S("dress color", "kıyafet rengi")
S("Shift=random, Ctrl=mix", "Shift=rastgele, Ctrl=karışık")

S("openGL & antialiasing mode", "openGL & antialiasing")

S("Date: %1 time: %2 s ", "Tarih: %1 zaman: %2 s ")
S("distance: %1\n", "uzaklık: %1\n")

// Camelot
// -------

N("Camelot", GEN_O, "Kamelot", "Kamelotlar", "Kamelotu", "Kamelotta")
N("wall of Camelot", GEN_F, "Kamelot Duvarı", "Kamelot Duvarları", "Kamelot Duvarını", "Kamelot Duvarıyla")
N("moat of Camelot", GEN_F, "Kamelot hendeği", "Kamelot hendekleri", "Kamelot hendeğini", "Kamelot hendeğiyle")
N("Round Table", GEN_O, "Yuvarlak Masa", "yuvarlak Masalar", "Yuvarlak Masayı", "Yuvarlak Masayla")
N("Knight", GEN_M, "Şövalye", "Şövalyeler", "Şövalyeyi", "Şövalyeyle")
N("Holy Grail", GEN_O, "Kutsal Kâse", "Kutsal Kâseler", "Kutsal Kâseyi", "Kutsal Kâseyle")

S(
  "The Knights of the Round Table are the greatest warriors of these lands. "
  "They are not very inventive with names though, as they call each of their "
  "castles Camelot. "
  "You are probably worthy of joining them, but they will surely give you "
  "some quest to prove yourself...\n\n"
  "Each castle contains a single treasure, the Holy Grail, in the center. "
  "The radius of the Round Table is usually 28, but after you find a Holy Grail "
  "successfully, each new castle (and each Round Table) you find will be bigger.",

  "Yuvarlak masa Şövalyeleri bu toprakların en müthiş savaşçıları. "
  "Kalelerine Kamelot demelerine bakılırsa, isimlerle araları pek iyi değil herhalde. "
  "Aralarına katılmaya büyük ihtimalle layıksın, ama yine de sana kendini kanıtlamak için bir görev verecekler... \n\n "
  "Her kale merkezinde tek bir hazineyi, Kutsal Kâseyi barındırıyor. "
  "Yuvarlak masanın çapı genelde 28'dir, ama Kutsal Kâseyi bir kez bulduğunda, karşılaştığın her yeni kale (ve her yuvarlak masa) eskisinden daha büyük olacak.")

S("It would be impolite to land on the table!",
  "Masaya çıkmak çok yakışıksız olur!")
S("You jump over the table!", "Masanın üstüne çıktın!")
S("That was not a challenge. Find a larger castle!",
  "Bu seni heyecanlandırmadı bile. Daha büyük bir kale bul!")
S("The Knights congratulate you on your success!",
  "Şövalyeler başarın için seni tebrik ediyor!")
S("The Knights laugh at your failure!",
  "Şövalyeler hezimetine katıla katıla gülüyor!")
S("The Knights stare at you!", "Şövalyeler sana dik dik bakıyor!")
S("Come on, this is too easy... find a bigger castle!",
  "Pöfff, çok kolaydı... daha büyük bir kale bul!")
S("The Knights wish you luck!", "Şövalyeler sana şans diliyor!")

S("\"I would like to congratulate you again!\"", "\"Seni tekrar tebrik etmek isterim!\"")
S("\"Find the Holy Grail to become one of us!\"", "\"Bizden biri olmak için Kutsal Kâseyi bul!\"")
S("\"The Holy Grail is in the center of the Round Table.\"", "\"Kutsal Kâse Yuvarlak Masanın merkezinde.\"")
S("\"I enjoy watching the hyperbug battles.\"", "\"Aşkınböcek savaşlarını izlemek hoşuma gidiyor.\"")
S("\"Have you visited a temple in R'Lyeh?\"", "\"R'Lyeh'teki tapınağı ziyaret ettin mi?\"")
S("\"Nice castle, eh?\"", "\"Kalemiz güzel, değil mi?\"")

// Temple
// ------

N("Temple of Cthulhu", GEN_F, "Cthulhu'nun Tapınağı", "Cthulhu'nun Tapınakları", "Cthulhu'nun Tapınağını", "Cthulhu'nun Tapınağında")
N("big statue of Cthulhu", GEN_O, "Cthulhu'nun Putu", "Cthulhu'nun Putları", "Cthulhu'nun Putunu", "Cthulhu'nun Putuyla")
N("Grimoire", GEN_F, "Kara Kitap", "Kara Kitaplar", "Kara Kitabı", "Kara Kitapla")
N("Cult Leader", GEN_M, "Kült Lideri", "Kült Liderleri", "Kült Liderini", "Kült Lideriyle")

S("The temple of Cthulhu consists of many concentric circles of columns. "
  "You will surely encounter many Cultists there, who believe that a pilgrimage "
  "to the inner circles will bring them closer to Cthulhu himself, and Grimoires "
  "which surely contain many interesting secrets.\n\n"
  "The circles in the temple of Cthulhu are actually horocycles. They are "
  "infinite, and there is an infinite number of them.",

  "Cthulhu tapınağı çok sayıda eş merkezli dairesel sütunlardan oluşur. "
  "Burada iç dairelere yapılan bir haccın kendilerini Cthulhu'ya daha çok yaklaştırdığına inanan bir çok Müritle ve çok ilginç sırlar içeren Kara Kitaplarla karşılaşacaksın. \n\n"
  "Cthulhu Tapınağının merkezindeki daireler aslında horoçemberler. Onlar sonsuz ve onlardan sonsuz tane var."
  )

S("The Grimoires contain many secrets of the Great Old Ones. "
  "Each new inner circle in the Temple of Cthulhu contains new Grimoires, with new secrets. "
  "You hope to read them when you return home, and to learn many things. "
  "The knowledge is valuable to you, but it is rather pointless to try to get "
  "several copies of the same Grimoire...",
  "Kara Kitaplar Eski Yücelere dair pek çok sır içerir. Cthulhu Tapınağındaki her iç daire yeni sırlar içeren yeni Kara Kitaplar içerir."
"Eve geri döndüğünde bunları okuyup pek çok şey öğrenmeyi umuyorsun. Bilgi senin için önemli, bu yüzden aynı Kara Kitaptan birden fazla almak çok anlamsız."
  )

S("These statues of Cthulhu are too large to carry, and they don't look too "
  "valuable anyway. Most monsters will never go through them... they probably have "
  "their reasons. But you can go! When you move into the cell containing "
  "a statue, you push the statue to the cell you left.\n",

  "Cthulhu putları taşımak için fazla büyük, zaten çok değerli de gözükmüyorlar. Canavarların çoğu onların içinden geçmiyor, bunun bir sebebi olmalı. "
"Ama sen bunların içinden geçebilirsin! Putun olduğu hücreye girdiğinde putu terkettiğin hücreye itersin. \n"
  )

S("These Cultists can push the statues, just like you.",
  "Bu Müritler putları tıpkı senin gibi itebilir.")

S("You already have this Grimoire! Seek new tomes in the inner circles.",
  "Bu Kara Kitaptan elinde zaten var! Yeni ciltleri iç dairelerde ara.")

S("You push %the1 behind you!", "%a1 arkana ittin.")

// More texts
// ----------

S("Your total kills", "Toplam leşler")

S(
  "In most lands, more treasures are generated with each enemy native to this land you kill. "
  "Moreover, 100 kills is a requirement to enter the Graveyard and the Hive.\n\n"
  "Friendly creatures and parts of monsters (such as the Ivy) do appear in the list, "
  "but are not counted in the total kill count.",

  "Çoğu diyarda, orada yaşayan canavarları öldürmen daha çok hazineyle karşılaşmanı sağlar. Ayrıca 100 leş Mezarlık ve Kovana girmen için bir önkoşuldur. \n\n"
"Dost yaratıklar ve canavarların parçaları (Sarmaşık gibi) litede gözükürt, ama toplam leşlere dahil edilmez.")

S("There must be some temples of Cthulhu in R'Lyeh...",
  "R'Lyeh'te Cthulhu'ya adanmış bazı tapınaklar olmalı...")

S("You overheard Hedgehog Warriors talking about emeralds...",
  "Kirpi Savaşçıların zümrütler hakkında konuştuğunu duydun...")

S("You overhear miners talking about a castle...",
  "Madencilerin bir kale hakkında konuştuğunu duydun...")

S("A castle in the Crossroads...", "Arayollarda bir Kale...")

S("You have to escape first!", "Önce kaçman gerekiyor!")
S("There is not enough space!", "Yeterince yer yok!")

S("Customize character", "Karakteri düzenle.")
S("gender", "cinsiyet")

S("Congratulations! You have found the Holy Grail!",
  "Tebrikler! Kutsal Kâseyi buldun!")

Orb("the Dragon", "Ejderha")

S("This Orb allows you to throw fire, just like the Fire Cultists.\n\n"
  "Each fire drains 5 charges. You are not allowed to throw fire into adjacent cells.",
//"Bu Küre tıpkı Ateş Müritleri gibi ateş atabilmeni sağlar."
  "Bu Küre tıpkı Ateş Müritleri gibi ateş atabilmeni sağlar.\n\nHer ateş 5 şarj tüketir, bitişik hücrelere ateş atamazsın."
  )

S("You throw fire!", "Ateş attın!")

Orb("Trickery", "Kandırma")

N("Illusion", GEN_F, "İlüzyon", "İlüzyonlar", "İlüzyonu", "İlüzyonla")

S("This Orb allows you to create illusions of yourself. Illusions are targeted "
  "by most monsters, just like yourself, Thumpers, and your friends.\n\n"
  "Each illusion takes 5 charges to create, and one extra charge "
  "per turn. You can also click your illusion to take it away, restoring 4 charges.\n\n"
  "If you have both Orb of Teleport and Orb of Trickery, Illusion is cast "
  "first -- you can then teleport on your Illusion to switch places with it.",
  "Bu Küre kendinin ilüzyonlarını çıkarmanı sağlar. İlüzyonlar tıpkı sen, Gümleyenler ve dostların gibi pek çok canavar tarafından saldırıya uğrayabilir.\n\n"
  "Her ilüzyonu çıkarması 5 şarj ve her ek tur bir şarj tüketir. İlüzyona tıklayarak onu yok edip, 4 şarjını geri alabilirsin. \n\n"
  "Aynı anda hem Kandırma hem Işınlanma Küren varsa, önce İlüzyon uygulanır, sonra istersen ilüzyonuna tıklayarak onla yer değiştirebilirsin. ")

S("You create an Illusion!", "Bir İlüzyon ürettin!")

S("You take the Illusion away.", "İllüzyonu yok ettin.")

S("Cannot teleport on a monster!", "Bir canavarın üzerine ışınlanamazsın!")
S("Cannot teleport on an item!", "Bir eşyanın üzerine ışınlanamazsın!")
S("Cannot teleport here!", "Buraya ışınlanamazsın!")
//S("You cannot teleport that far away!", "O kadar uzağa ışınlanamazsın!")

S("You cannot target that far away!", "O kadar uzağı hedefleyemezsin.")
S("You cannot target that close!", "O kadar yakını hedefleyemezsin!")
S("Cannot cast illusion on an item!", "Bir eşyanın üzerinde ilüzyon oluşturamazsın!")
S("Cannot cast illusion here!", "Burada ilüzyon oluşturamazsın!")
S("Cannot cast illusion on a monster!", "Bir canavarın üzerinde ilüzyon oluşturamazsın!")
S("Cannot throw fire there!", "Oraya ateş atamazsın!")

S("Illusions are targeted "
  "by most monsters, just like yourself, Thumpers, and your friends.",
  "İlüzyonlar tıpkı sen, Gümleyenler ve dostların gibi pek çok canavar tarafından saldırıya uğrayabilir.")

S("or ESC to see how it ended", "veya nasıl bittiğini görmek için ESC'ye bas")
S("high contrast", "yüksek kontrast")
S("draw the heptagons darker", "yedigenleri daha koyu çiz")
S("targetting ranged Orbs Shift+click only",
  "menzilli küreler için sadece Shift+sol tık")
S("Shift+F, Shift+O, Shift+T, Shift+L, Shift+U, etc.",
  "Shift+F, Shift+O, Shift+T, Shift+L, Shift+U, vb.")
S("also hold Alt during the game to toggle high contrast",

  "ayrıca oyun sırasında Alt'a basılı tutarak yüksek kontrastı açıp kapatabilirsin.")

// Crossroads II
// -------------

N("Crossroads II", GEN_N, "Arayollar 2", "Arayollar 2'ler", "Arayollar 2'yi", "Arayollar 2'de")

S(
  "An alternate layout of the Crossroads. It is more dense and more regular, "
  "although you won't find the castle of Camelot here.",

  "Arayolların alternatif bir versiyonu. Daha yoğun ve daha düzenli, ama Kamelot'un kalesini burada bulamazsın.")

// Caribbean
// ---------

N("Caribbean", GEN_M, "Karayipler", "Karayip", "Karayipleri", "Karayiplerde")

N("Pirate", GEN_M, "Korsan", "Korsanlar", "Korsanı", "Korsanla")
N("Shark", GEN_M, "Köpekbalığı", "Köpekbalıkları", "Köpekbalığını", "Köpekbalığıyla")
N("Parrot", GEN_F, "Papağan", "Papağanlar", "Papağanı", "Papağanla")
N("Pirate Treasure", GEN_M, "Korsan Hazinesi", "Korsan Hazineleri", "Korsan Hazinesini", "Korsan Hazinesiyle")
N("Compass", GEN_M, "Pusula", "Pusulalar", "Pusulayı", "Pusulayla")

N("sea", GEN_F, "deniz", "denizler", "denizi", "denizle")
N("boat", GEN_F, "kayık", "kayıklar", "kayığı", "kayıkla")
N("island", GEN_F, "ada", "adalar", "adayı", "adayla")
N("tree", GEN_N, "ağaç", "ağaçlar", "ağacı", "ağaçla")

Orb("Time", "Zaman")

S("This dangerous sea contains nasty sharks and pirates. ",
  "Bu tehlikeli deniz vahşi köpekbalıkları ve korsanlar barındırıyor.")

S("The islands of Caribbean are infinite and circular, and "
  "the pirates probably have hidden their treasures somewhere far from the coast.",
  "Karayip Adaları sonsuz ve dairesel. Korsanlar hazinelerini büyük ihtimalle kıyılardan uzak yerlere saklıyordur.")

S(
    "Hyperbolic pirates do not need huge ships, since so many lands to conquest "
    "are so close. These small boats are enough for them.\n\n"
    "Boats allow you to go through water. If you are in a boat, you can move into "
    "a water cell (and the boat will come with you).",

    "Hiperbolik korsanlar yakınlarda fethedilecek bir sürü toprak olduğundan devasa gemilere ihtiyaç duymuyor. "
    "Bu küçük kayıklar onlar için yeterli.\n\n"
    "Kayıklar suda ilerleyebilmeni sağlıyor. Eğer bir kayık içindeysen, bir su hücresine ilerleyebilirsin. (Ve kayık da seninle birlikte gelir). ")

S(
    "The forests of Caribbean are too dense to be traversed by humans, "
    "and they are hard to burn. Many colorful parrots can be found there.",
    "Karayip Ormanları insanlar tarafından gezilmek için fazla yoğun, ve yanmaya da dirençli. "
    "Buralarda bir sürü, renkli papağana rastlayabilirsin.")

S("Ye wonder where did th' Pirates find all these riches...",
    "Korsanların bu kadar serveti nereden bulduğunu merak ediyorsun...")

S(
  "The hyperbolic pirates have no use for treasure maps. However, they have found "
  "out that a compass points to the center of the island. So they just go as "
  "far towards the center as they can, and hide their treasure there.",

  "Hazine haritalarının hiperbolik korsanlar için bir değeri yok. "
  "Ancak, adanın ortasını gösteren bir pusula keşfettiler. "
  "Böylece, ortaya doğru olabildiğince ilerler ve hazinelerini orada saklarlar.")

S("Just a nasty shark.", "Sadece vahşi bir köpekbalığı.")

S("Parrots feel safe in the forests of Caribbean, so they "
    "never leave them. But they will help the Pirates by attacking the intruders.",

  "Papağanlar Karayip Ormanlarında güvende hissederler, bu yüzden buraları hiç terketmezler. İçeriye girenlere saldırarak korsanlara da yardım etmiş olurlar. ")

S("Just a typical hyperbolic pirate.", "Sadece bildiğiniz bir hiperbolik korsan.")

S(
    "Normally, the power of most Orbs slowly fades away, even when "
    "you are not actively using them. This Orb prevents this.\n\n"

    "When you have the Orb of Time, Orbs which are not active won't lose their power. "
    "Orbs are considered active if they have a continuous power which has actually "
    "affected something in the last turn.\n\n"

    "Orbs of Shielding remain active after being activated (even if you are no longer "
    "attacked), and Orbs of Time have a bigger cap inside their native Caribbean than "
    "outside.",

    "Normalde Kürelerin güçleri ,onları aktif olarak kullanmadığında bile, yavaşça azalır. Bu Küre bunu engeller.\n\n"

    "Zaman Küresine sahip olduğunda aktif olmayan küreler güçlerini kaybetmez. Sürekli gücü olan küreler eğer son turda bir şey etkiledilerse aktif sayılır.\n\n"

    "Kalkan Küresi aktifleştirdikten sonra da (saldıraya uğramasan bile) aktif kalır.  "
    "Ayrıca Zaman Küresinin sınırı onların bulunduğu Karayiplerde daha fazladır.")

// Achievements
// ------------

// Parrot : Find and collect Pirate Treasure.
// Caribbean Shark : Collect 10 Pirate Treasures.
// Pirate : Collect 25 Pirate Treasures.
// Master of Caribbean : Collect 50 Pirate Treasures.

// Papağan : Bir Korsan Hazinesi bul ve topla.
// Karayip Köpekbalığı : 10 Korsan Hazinesi topla.
// Korsan : 25 Korsan Hazinesi topla.
// Karayip Korsanı : 50 Korsan Hazinesi topla.

// Red Rock Valley
// ---------------

N("Red Rock Valley", GEN_F, "Kızılkaya Vadisi", "Kızılkaya Vadileri", "Kızılkaya Vadisini", "Kızılkaya Vadisinde")

N("Rock Snake", GEN_M, "Kaya Yılanı", "Kaya Yılanları", "Kaya Yılanını", "Kaya Yılanıyla")
N("Rock Snake Tail", GEN_O, "Kaya Yılanı Kuyruğu", "Kaya Yılanı Kuyrukları", "Kaya Yılan Kuyruğunu", "Kaya Yılan Kuyruğuyla")
N("Red Troll", GEN_M, "Kızıl Trol", "Kızıl Troller", "Kızıl Trolü", "Kızıl Trolle")
N("Red Gem", GEN_M, "Kızıl Mücevher", "Kızıl Mücevherler", "Kızıl Mücevheri", "Kızıl Mücevherle")

N("rock I", GEN_F, "kaya I", "kayalar  I", "kayayı I", "kayayla I")
N("rock II", GEN_F, "kaya II", "kayalar  II", "kayayı II", "kayayla II")
N("rock III", GEN_F, "kaya III", "kayalar III", "kayayı III", "kayayla III")

Orb("Space", "Boşluk")

S("Not enough power for telekinesis!", "Telekinezi için yeterince güç yok!")

S("This land contains high rock formations. Most of the valley is at level 0, "
  "while items are found at level 3. It is impossible to gain two or more levels, "
  "or to lose three levels, in a single move, (attacks are possible at any "
  "difference, though). Kill Red Trolls and Rock Snakes to make a cell higher.",

  "Bu diyar kaya oluşumları barındırır. Vadinin çoğu yükseklik 0'dadır, eşyalar ise yükseklik 3'te bulunabilir. "
  "Tek hamlede iki veya daha fazla yükseklik kazanamaz yahut üç veya daha fazla yükseklik kazanamazsın. (ama yükseklikler arası saldırılar mümkün). Kızıl Trolleri ve Kaya Yılanlarını öldürerek bir hücreyi yükseltebilirsin. ")

S("A kind of Troll native to the Red Rock Valley.",
  "Kızılkaya Vadisinde yaşayan bir trol.")

S(
  "Rock snakes are similar to Sandworms, but they move each turn. However, they "
  "only move on the hexagonal cells. They are also somewhat longer than the Sandworms.",

  "Kaya yılanları her tur hareket etmesi hariç Kumkurtlarına benzer. Ayrıca, sadece altıgen hücrelerde hareket ederler. Kumkurtlarından bir nebze daha genişlerdir. ")

S("A gem from the Red Rock Valley.", "Kızılkaya Vadisinden bir kızıl mücevher.")

S(
    "This Orb is able to bring faraway items to your location, even if there are "
    "monsters or barriers on the way. The cost of "
    "bringing an item (in charges) equals the square of its distance to you. Contrary "
    "to some other Orbs, usage is not allowed if you have not enough power left.",

  "Bu küre uzaktaki eşyaları , arada canavar yahut engeller olup olmadığı farketmeksizin, senin olduğun hücreye getirir. Bu işlem eşyanın uzaklığı kadar güç tüketir. Bazı Kürelerin aksine, güç yoksa bu küreyi kullanamazsın.")

// Climber : Find and collect a Red Gem.
// Red Troll : Collect 10 Red Gems.
// Rock Snake : Collect 25 Red Gems.
// Master of Red Rock : Collect 50 Red Gems.

// Tırmanan : Bir Kırmızı Mücevher bul ve topla.
// Kızıl Trol : 10 Kırmızı Mücevher topla.
// Kaya Yılanı : 25 Kırmızı Mücevher topla.
// Kızılkaya Efendisi : 50 Kırmızı Mücevher topla.

// missing sentences

S("%The1 drowns!", "%1 boğuldu!")
S("%The1 falls!", "%1 düştü!")

// these were missing from the translation for some reason

S("Hell has these lakes everywhere... They are shaped like evil stars, and filled with burning sulphur.",
  "Cehennemde her yerde bunun gibi göller var. Şeytani star şeklinde ve yanan sülfürle dolu...")

// Hardcore Mode
// -------------

S("hardcore mode", "Aşmış mod")

S("One wrong move and it is game over!", "Tek bir yanlış hamle ve oyun biter!")
S("Not so hardcore?", "O kadar da aşmış değil?")

// Shoot'em up Mode
// ----------------

S("shoot'em up mode", "tryb strzelanki")
S("Welcome to the Shoot'em Up mode!", "Witaj w trybie strzelanki!")
S("F/;/Space/Enter/KP5 = fire, WASD/IJKL/Numpad = move", "F/;/Space/Enter/KP5 = strzał, WASD/IJKL/Numpad = ruch")

N("Rogue", GEN_M, "Seyyah", "Seyyahlar", "Seyyahı", "Seyyahla")
N("Knife", GEN_M, "Bıçak", "Bıçaklar", "Bıçağı", "Bıçakla")
N("Flail", GEN_M, "Topuz", "Topuzlar", "Topuzu", "Topuzla")
N("Fireball", GEN_F, "Ateş Topu", "Ateş Topları", "Ateş Topunu", "Ateş Topuyla")
N("Tongue", GEN_O, "Dil", "Diller", "Dili", "Dille")

S("In the Shoot'em Up mode, you are armed with thrown Knives.",
  "SHMUP modunda silahın fırlatılabilen bıçaklar.")
S("A simple, but effective, missile, used by rogues.",
  "Seyyahlar tarafından kullanılan basit ama etkili bir silah.")
S("This attack is likely to hit the attacker.",
  "Bu saldırı büyük ihtimalle saldırganı vuracaktır.")
S("This magical missile burns whatever it hits.", "Bu büyülü saldırı değdiği şeyi yakar.")
S("Some monsters have long tongues, which allow them to attack enemies in nearby cells.",
  "Bazı canavarlar uzun dillere sahip, böylece yakındaki hücrelere saldırabiliyorlar.")

// modes for the local highscores
// ------------------------------

S(", m - mode: normal", ", m - normal mod")
S(", m - mode: hardcore only", ", m - aşmış mod")
S(", m - mode: shoot'em up", "m - SHMUP modu")

// update description for Steam
// ----------------------------

// (SHMUP modu ve bedava versiyonda olmayan iki yeni diyar, ve daha fazlası eklenecek!)

S("You would get hurt!", "Orada hasar alırsın!")
S("PARTIAL", "KISMÎ")

S("Cannot drop %the1 here!", "Ölü Küreyi buraya bırakamazsın!")

// Euclidean scores
// ----------------

S(" (E:%1)", " (Ö:%1)")

S("You cannot attack Rock Snakes directly!", "Kaya Yılanlarına doğrudan saldıramazsın!")

S("\"I am lost...\"", "Kayboldum...")

S("You are killed by %the1!", "%1 tarafından öldürüldün!")


// achievements from Version 7.0 which have not yet been translated

//AN IDEA FOR A NEW GAME MOD: a mini game where you can choose which land you are starting in, and world generates only that land.
//No achievement is possible, it is only good for training, or trying new lands.
//Every different land in that level is unlocked by visiting the mentioned land once.

// Hardcore : Get the Orb of Yendor in the Hardcore mode.
// Knife Master : Get the Orb of Yendor in the Shoot'em Up mode.

// achievements from Version 7.0 which have not yet been translated

// Hardcore : Aşmış modda Yendor'un küresini ele geçir.
// Bıçakçı : SHMUP modunda Yendor'un Küresini ele geçir.
// new menu for Version 7.1

//correction for Great Wall. I mistakenly translated it as Wall of China, since back then I did not know the context. Below is a better translation.
N("Great Wall", GEN_M, "Büyük Duvar", "Büyük Duvarları", "Büyük Duvarı", "Büyük Duvarda")

S("(v) menu", "(v) menü")
S("go back", "dön")
S("return to the game", "oyuna dön")
S("or 'v' to see the main menu", "veya ana menüyü görmek için 'v'ye bas.")

S("HyperRogue %1", "HyperRogue %1")
S("basic configuration", "temel ayarlar")
S("advanced configuration", "gelişmiş ayarlar")
S("local highscores", "yerel yüksek skorlar")
S("help", "yardım")
S("restart game", "oyunu yeniden başlat")
S("special game modes", "özel oyun modları")
S("save the game", "oyunu kaydet")
S("quit the game", "oyundan çık")
S("review your quest", "görevine gözat")
S("review the scene", "durumu gör")
S("game over screen", "oyun bitiş ekranı")
S("continue game", "oyuna devam et")
S("play the game!", "oyna!")

// fixed descriptions for Shmup achievements
// -----------------------------------------

S("You have used less knives than ever before. Congratulations!",
  "Her zamankinden daha az bıçak kullandın. Tebrikler!")

S("You have improved both your real time and knife count. Congratulations!",
  "Hem toplam zamanını hem de bıçak sayını geliştirdin. Tebrikler!")

S("%1 knives (%2)", "bıçaklar: %1 (%2)")

// temporary
S("No description yet." ,"Henüz bir açıklama yok.")

// special case when no Spice is visible
S("The sandworm explodes!", "Kumkurdu patladı!")

// Ocean
// -----

// achievements:
// Reached Ocean: Find and collect an Amber.
// Albatross: Collect 10 Ambers.
// Amber Albatross: Collect 25 Ambers.
// Master of the Tides: Collect 50 Ambers.
// achievements:
// Okyanus'a Ulaş: Bir Kehribar topla.
// Albatros: 10 Kehribar topla.
// Kehribar Albatros: 25 Kehribar topla.
// Dalgaların Efendisi: 50 Kehribar topla.

N("Ocean", GEN_O, "Okyanus", "Okyanuslar", "Okyanusu", "Okyanusla")

S(
    "You can collect some valuable Ambers on the coast, but beware the tides!\n\n"
    "You can also take one of the boats and venture into the Ocean, "
    "to find other coasts, dangerous whirlpools, and islands inhabited by Pirates.",

  "Kıyıdan çok değerli kehribarlar toplayabilirsin, ama dalgalara dikkat et!\n\n"
  "Kayıklardan birini alıp , başka kıyılar, tehlikeli tayfunlar ve"
  "korsanların egemenliğindeki adalar bulmak için okyanusa açılabilirsin.")

N("Albatross", GEN_O, "Albatros", "Albatroslar", "Albatrosu", "Albatrosla")

S(
  "Those large seabirds attack you for some reason. At least they are not "
  "as fast as Eagles...",
  "Bu iri denizkuşları sana nedense saldırıyor. En azından kartallar kadar hızlı değiller.")

N("stranded boat", GEN_F, "terkedilmiş bot", "terkedilmiş botlar", "terkedilmiş botu", "terkedilmiş botla")

S(
  "This boat cannot go through the sand. But if you sit inside and "
  "wait for the tide, you will be able to use it to travel through the Ocean.",

  "Bu bot kumda hareket edemez. Ama içine oturur ve dalgayı beklersen bunu OKyanus'ta seyahat etmek için kullanabilirsin."
  )

N("Ocean", GEN_O, "Okyanus", "Okyanuslar", "Okyanusu", "Okyanusla")

N("Amber", GEN_O, "Kehribar", "Kehribarlar", "Kehribarı", "Kehribarla")

S(
  "When the tide is away, beautiful ambers can be found on the hyperbolic beaches. "
  "Perhaps there used to be a forest here?",
  "Dalga uzaktayken şahane kehribarlar hiperbolik kumsallarda bulunabilir. "
  "Belki önceleri burada bir orman vardı?"
  )

Orb("Air", "Hava")

S("This Orb allows you to blow your enemies away.\n\n"
  "Click a monster to blow it one cell away. It cannot be used against mimics, ghosts, sharks and other monsters restricted to a specific terrain, and multi-tile monsters.",
  "Bu Küre düşmanları rüzgârla uzağa ittirmene yarar.\n\n"
  "Bir canavara tıklayarak onu rüzgârla bir hücre ittirebilirsin. Bu özellik, taklitçilere, hayaletlere, köpekbalıklarına, çok hücreli canavarlara ve belli bir araziye özgü canavarlara karşı kullanılamaz."
  )

N("Sea Border", GEN_O, "Deniz Sınırı", "Deniz Sınırları", "Deniz Sınırını", "Deniz Sınırında")

S("Border between seas.", "Denizler arasındaki sınır.")

// Whirlpool
// ---------

// achievements:
// Escaped Whirlpool: Collect a Pearl, and escape the Whirlpool.
// Vortex Shark: Collect 10 Pearls.
// Vortex Pirate: Collect 25 Pearls.
// Master of the Whirlpool: Collect 50 Pearls.

// Tayfundan Kaç: Bir İnci Topla ve Tayfundan Kaç.
// Kasırga Köpekbalığı: 10 inci Topla.
// Kasırga Korsanı: 25 İnci Topla.
// Tayfunun Efendisi: 50 İnci Topla.

N("Whirlpool", GEN_O, "Tayfun", "Tayfunlar", "Tayfunu", "Tayfunda")

S(
  "Many lost boats are spinning in this whirlpool. Some of them contain treasures "
  "and Pirates.\n\n"
  "Unmanned boats will go one cell clockwise in each turn. Sharks and manned boats "
  "are only allowed to go with the current, that is, towards the center, or clockwise.",

  "Bu tayfunda pek çok kayıp kayık geziniyor. Bır kısmında hazineler yahut korsanlar var.\n\n"
  "İnsansız kayıklar her tur saat yönünde bir hücre hareket eder. Köpekbalıkları ve içinde insan olan kayıklar sadece akıntıyla -yani merkeze doğru- ya da saat yönünde hareket edebilir."
  )

N("Pearl", GEN_F, "İnci","İnciler","İnciyi","İncide")

S(
  "You do not know exactly why, but there are valuable pearls on many boats "
  "in the whirlpool.",
  "Nedeni bilinmez ama, pek tayfunun içindeki pek çok botta değerli inciler var."
  )

Orb("Water", "Su")

S( "This Orb allows your boat to go against the current, "
   "and also to go into the land, creating water on the way.",
   "Bu Küre akıntıya karşı hareket edebilmene imkân verir. Ayrıca bu küreyle karaya doğru hareket edip yolunda su çıkararak ilerleyebilirsin.")

S("You cannot go against the current!", "Akıntıya karşı hareket edemezsin!")

// Minefield
// ---------

// achievements:
// Reached Minefield: Collect a Bomberbird Egg.
// Minesweeper: Collect 10 Bomberbird Eggs.
// Bomberbird: Collect 25 Bomberbird Eggs.
// Master of the Minefield: Collect 50 Bomberbird Eggs.

// achievements:
// Mayıntarlasına Ulaş: Bir Bombacıkuş Yumurtası topla.
// Mayın Tarayıcı: 10 Bombacıkuş Yumurtası topla.
// Bombacıkuş: 25 Bombacıkuş Yumurtası topla.
// Mayıntarlası Efendisi: 50 Bombacıkuş Yumurtası topla.

N("Minefield", GEN_N, "Mayıntarlası", "Mayıntarlaları", "Mayıntarlasını", "Mayıntarlasında")
N("minefield", GEN_N, "mayıntarlası", "mayıntarlaları", "mayıntarlasını", "mayıntarlasıyla")
N("cell without mine", GEN_N, "mayınsız hücre", "mayınsız hücreler", "mayınsız hücreyi", "mayınsız hücreyle")

S(
  "This minefield has been created by the Bomberbirds to protect their valuable eggs. "
  "Mines explode when they are stepped on, creating fire all around them "
  "(this fire never expires in the Minefield). If you don't step on a mine, you "
  "know the number of mines in cells around you. These numbers are marked with "
  "color codes on the cells you have visited.",
  "Bu mayıntarlası Bombacıkuşlar tarafından değerli yumurtalarını korumak için düzenlenmiş."
"Mayınlar üzerine basınca etrafında ateş çıkararak patlıyor"
"(Mayıntarlasında bu ateş zamanla sönmez). Eğer bir mayına basmazsan, etrafındaki mayın sayısını bilebilirsin."
"Bu sayılar daha önce ziyaret ettiğin hücrelerde farklı renk kodlarıyla işaretlidir."
  )

N("Bomberbird", GEN_O, "Bombacıkuş", "Bombacıkuşlar", "Bombacıkuşunu", "Bombacıkuşuyla")

S(
    "Dark red birds who have created the minefield.\n\n"
    "They create a mine on the spot where they are killed, provided "
    "that the terrain is suitable. Also note that mines are triggered "
    "by dead birds falling on them.",

    "Mayıntarlasını düzenleyen kızıl, siyah kuşlar.\n\n"
    "Öldüklerinde öldükleri hücrede, eğer hücre tipi uygunsa bir mayın çıkarırlar. "
    "Ayrıca dikkat, mayınlar, üzerine düşen ölü kuşlarla da tetiklenebilir.")

N("Tame Bomberbird", GEN_O, "Sakin Bombacıkuş", "Sakin Bombacıkuşlar", "Sakin Bombacıkuşunu", "Sakin Bombacıkuşuyla")

S(
  "This bomberbird will follow you at some distance, and attack your enemies. "
  "You can kill it to place a mine.",

  "Bu bombacıkuş seni belli bir mesafeden takip eder ve düşmanlarına saldırır. Onu öldürerek bir mayın döşeyebilirsin.")


N("Bomberbird Egg", GEN_N, "Bombacıkuş Yumurtası", "Bombacıkuş Yumurtaları", "Bombacıkuş Yumurtasını", "Bombacıkuş Yumurtasıyla")

S(
  "Bomberbird eggs are big and tasty, and thus valuable. "
  "They can hatch when left alone for some time (but this will never happen "
  "if you are watching).",

  "Bombacıkuş yumurtaları büyük ve lezzetlidir, bu sebeple değerlidir. Eğer yalnız bırakılırlarsa çatlayabilirler. (Ama bu sen izlerken olmaz.)"
  )

Orb("Friendship", "Dostluk")

S("This Orb summons a friendly Bomberbird.",
  "Bu Küre barışçıl bir Bombacıkuş çıkarır.")

S("Nowhere to blow %the1!", "%a1! ittirecek bir yer yok!")
S("%The1 is immune to wind!", "%1 rüzgârdan etkilenmiyor!")
S("You blow %the1 away!", "%a1! rüzgârla ittirdin!")

S("WARNING: you are entering a minefield!", "UYARI: bir mayıntarlasına giriyorsun!")
S("No mines next to you.", "Yakınında hiç mayın yok.")
S("A mine is next to you!", "Yakınında bir mayın var!")
S("Two mines next to you!", "Yakınında iki mayın var!")
S("Three mines next to you!", "Yakınında üç mayın var!")
S("Four mines next to you!", "Yakınında dört mayın var!")
S("Five mines next to you!", "Yakınında beş mayın var!")
S("Six mines next to you!", "Yakınında altı mayın var!")
S("Seven mines next to you!", "Yakınında yedi mayın var!")

S("Still confused? Read the FAQ on the HyperRogue website!\n\n",
  "Hâlâ karışık mı geliyor? HyperRogue vebsitesinden SSS'i okuyun! \n\n")

S("You have to run away from the water!", "Sudan kaçmak zorundasın!")

//N("Icewolf", GEN_M, "Buzkurdu", "Buzkurtları", "Buzkurdunu", "Buzkurduyla")

// VERSION 7.2
// ===========

// Palace
// ------

N("Palace", GEN_O, "Saray", "Saraylar", "Sarayı", "Sarayda")
N("palace wall", GEN_F, "Saray Duvarı", "Saray Duvarları", "Saray Duvarını", "Saray Duvarı")

S("Apparently a princess is kept locked somewhere, but you won't ever find her in this hyperbolic palace. ",
  "Görünen o ki, bir prenses bir yerlerde saklı tutuluyor, ama bu hiperbolik sarayda onu bulman mümkün değil. ")

S("Apparently a prince is kept locked somewhere, but you won't ever find him in this hyperbolic palace. ",
  "Görünen o ki, bir şehzade bir yerlerde saklı tutuluyor, ama bu hiperbolik sarayda onu bulman mümkün değil. ")

S("So better just to concentrate on collecting treasure. "
  "Beware the traps, and the guards, who are hard to kill!",

  "Yani sadece hazineleri toplamaya odaklansan iyi olur. "
  "Tuzaklara dikkat! Öldürmesi pek zor olan muhafızlara da dikkat et!"
  )

N("trapdoor", GEN_N, "tuzak kapısı", "tuzak kapıları", "tuzak kapısını", "tuzak kapısıyla")
S("This floor will fall after someone goes there. Go quickly!",
  "Bu zemin birisi oradan geçtikten sonra çöker! Çabuk uzaklaş!")

N("closed gate", GEN_F, "kapalı kapı", "kapalı kapılar", "kapalı kapıyı", "kapalı kapıyla")
N("open gate", GEN_F, "açık kapı", "açık kapılar", "açık kapıyı", "açık kapıyla")
N("closing plate", GEN_F, "kapanan levha", "kapanan levhalar", "kapanan levhayı", "kapanan levhayla")
N("opening plate", GEN_F, "açılan levha", "açılan levhalar", "açılan levhayı", "açılan levhayla")

S("Green pressure plates open all gates in radius 3 around them. "
  "Similarly, red pressure plates close all gates in this radius.",

  "Yeşil baskı levhaları 3 uzaklıktaki bütün kapıları açar. "
  "Aynı şekilde, kırmızı baskı levhaları bu komşuluktaki kapıları kapatır.")

N("Hypersian Rug", GEN_O, "Aşkınlı Kilim", "Aşkınlı Kilimler", "Aşkınlı Kilimi", "Aşkınlı Kilimle")
S("Nice, a hyperbolic rug! It will not fit very well on your flat Euclidean floor, but who cares?",
  "Harika! Bir hiperbolik kilim! Evindeki öklidyen zemine pek yakışmayacak, ama kimin umrunda!")

Orb("the Frog", "Kurbağa")
S("This Orb lets you jump to a place which is two cell away from you, in a single turn. "
  "You can jump over water, chasms and fire, but not over walls.",
  "Bu Küre tek tur içinde senden iki hücre uzağa zıplamanı sağlar.")
S("Cannot jump through %the1!", "%1 hücresinden zıplayamazsın!")
S("You jump!", "Zıpladın!")

S("\n\nNote: when pushing %the1 off a heptagonal cell, you can control the pushing direction "
  "by clicking left or right half of the heptagon.",
  "\n\nNot:  %a1 bir yedigensel hücreden iterken, itmenin yönünü yedigenin sol ve sağ yarısına tıklayarak belirleyebilirsin."
  )

S(" With the keyboard, you can rotate the view for a similar effect (Page Up/Down).",
  " Klavyeyle görüntüyü döndürerek benzer bir etki yakalayabilirsin. (Page Up/Down).")

N("Palace Guard", GEN_M, "Saray Muhafızı", "Saray Muhafızları", "Saray Muhafızını", "Saray Muhafızıyla")

S("You have to hit Palace Guards several times to kill them. After each hit, they "
  "are pushed away and stunned for some time.",
  "Saray Muhafızlarının ölmesi için onlara bir kaç kere vurmalısın. Her vuruştan sonra geri itilirler ve birkaç turluk sersemlerler.")

N("Fat Guard", GEN_M, "Şişman Muhafız", "Şişman Muhafızlar", "Şişman Muhafızı", "Şişman Muhafızla")

S("Fat guards are too heavy to be pushed away by your hits.",
  "Şişman Muhafızlar vuruşlarınla geriye itilmek için fazla ağır.")

N("Skeleton", GEN_M, "Kościotrup", "Kościotrupy", "Kościotrupa", "Kościotrupem")
S("Skeletons work similar to Palace Guards, but they won't die no matter how many "
  "times you hit them. Well, you have to be more creative...\n\n"
  "Skeletons attacked outside of their native land, Palace, are stunned for a longer time.",
  "İskeletler Saray Muhafızlarına benzerdir, ama kaç sefer vurulurlarsa vurulsunlar ölmezler. "
  "Onları öldürmek için daha yaratıcı olmanız gerekiyor... \n\n Sarayın dışında darbe alan iskeletler daha uzun süre için sersemlerler."
  )

N("Vizier", GEN_M, "Vezir", "Vezirler", "Veziri", "Vezirler")
S("Viziers are neither pushed away nor stunned. However, you attack them automatically when "
  "escaping from them.",
  "Vezirler sersemlemez ve geriye itilmez, onlardan kaçarken otomatik olarak onlara saldırmış olursun.")

S("You stun %the1.", "%a1 sersemlettin.")
S("The gate is closing right on you! RUN!", "Kapı üzerine kapanıyor! KAÇ!")
S("%The1 is crushed!", "%1 ezildi!")
S("You hit %the1.", "%1 düşmanına vurdun.")
S("Hit him by walking away from him.", "Ona ondan uzaklaşarak vur.")
S("Hmm, he has been training in the Emerald Mine. Interesting...", "Çok garip... Zümrüt Madeninde alıştırma yapıyormuş.")

// Reached the Palace: Find and collect a Hypersian Rug.
// Palace Guard: Collect 10 Hypersian Rugs.
// Vizier: Colect 25 Hypersian Rugs.
// Prince: Colect 50 Hypersian Rugs.

// Saraya Ulaş: Bir Aşkınlı Kilim bul ve topla.
// Saray Muhafızı: 10 Aşkınlı Kilim topla.
// Vezir: 25 Aşkınlı Kilim topla.
// Şehzade: 50 Aşkınlı Kilim topla.

// Living Fjord
// ------------

N("Living Fjord", GEN_O, "Yaşayan Fiyort", "Yaşayan Fiyortlar", "Yaşayan Fiyortu", "Yaşayan Fiyortta")

S("A coastal area, from where you can get both to the inland worlds and to the Ocean. "
  "Each turn, each cell will become water or earth, based on the majority of cells around it. "
  "Contrary to the Living Caves, this process is not affected by most items and monsters, "
  "but elementals, dead Trolls, and cells outside of the Living Fjord have "
  "a very powerful effect.",
  "Sahil şeridinde bir bölge, buradan hem iç diyarlara hem de Okyanus'a geçebilirsin. "
  "Her tur, her hücre etrafındaki hücrelerin çoğunluğuna göre su veya toprak olacak. "
  "Yaşayan Mağaraların aksine, bu süreç eşyalar veya canavarlardan etkilenmez. "
  "Ancak Özütler, Ölü Troller ve Yaşayan Fiyortların dışındaki hücrelerin etkisi çok güçlüdür."
  )

N("Fjord Troll", GEN_M, "Fiyort Trolü", "Fiyort Trolleri", "Fiyort Trolünü", "Fiyort Trolüyle")
S("Fjord Trolls leave a wall when they die, causing the living fjord to rise around it. "
  "Contrary to Rock Trolls, items around are not destroyed.",
  "Fiyort Trolleri öldüklerinde geriye bir duvar bırakıp cesetlerinin etrafına yaşayan fiyortun yükselmesine sebep olurlar. "
  "Kaya Trollerinin aksine etraflarındaki eşyalar yok olmaz."
  )

N("Viking", GEN_M, "Viking", "Vikingler", "Vikingi", "Vikingle")
S("Mighty warriors from the Fjord, who can use boats.",
  "Fiyortun kayık kullanabilen kudretli savaşçıları.")

N("Water Elemental", GEN_M, "Su Özütü", "Su Özütleri", "Su Özütünü", "Su Özütüyle")
S("Wherever this powerful being goes, the living fjord "
  "sinks below water, non-magical boats are destroyed, and fires are extinguished.\n\n"
  "As a special case, you can attack the Water Elemental from the water, without drowning immediately.",
  "Bu güçlü yaratığın geçtiği her yerde Yaşayan Fiyort su altına gömülür, sihirli olmayan kayıklar yok olur ve ateşler söner. \n\n "
  "İstisna bir durum olarak Su Özütüne suyun içerisinden hemen boğulmadan vurursan onu öldürebilirsin. ")

N("Garnet", GEN_O, "Nartaşı", "Nartaşları", "Nartaşını", "Nartaşıyla")

S("Vikings believe that garnets improve their strength.",
  "Vikingler nartaşlarının güçlerini artırdığını düşünür.")

Orb("the Fish", "Balık")
S("This Orb lets you dive into the water. While diving, you are able to see and collect underwater treasures, "
  "while being invisible to monsters yourself. You are afraid of jumping into the water straight from a boat, so usually you won't do it.",
  "Bu Küre suya dalabilmeni sağlar. Suyun altındayken suyun altını görebilir ve sualtı hazinelerini toplayabilirsin. Bunu yaparken canavarlar seni göremez."
  "Korkun sebebiyle bir kayıktan suya genelde doğrudan atlayamıyorsun.")

S("%The1 is washed away!", "%1 suya karışıp gitti!")
S("%The1 is extinguished!", "%1 söndü!")

// Reached the Living Fjord: Find and collect a Garnet.
// Viking: Collect 10 Garnets.
// Water Elemental: Colect 25 Garnets.
// Master of the Fjord: Colect 50 Garnets.

// Yaşayan Fiyortlara Ulaş: Bir Nartaşı bul ve topla.
// Viking: 10 Nartaşı topla.
// Su Özütü: 25 Nartaşı topla.
// Fiyort Efendisi: 50 Nartaşı topla.

Orb("Discord", "İhtilaf")

S("Causes most monsters to attack other monsters, not only you and your friends.",
  "Çoğu canavarın sen ve dostların yanında diğer canavarlara da saldırmasına sebep olur.")

// Shmup Configuration
// -------------------

S("forward", "ileri")
S("backward", "geri")
S("turn left", "sola dön")
S("turn right", "sağa dön")
S("move up", "yukarı git")
S("move right", "sağa git")
S("move down", "aşağı git")
S("move left", "sola git")
S("throw a knife", "bıçak at")
S("face the pointer", "mausa bak")
S("throw at the pointer", "mausa doğru at")
S("drop Dead Orb", "Ölü Küreyi bırak")
S("center the map on me", "centruj mapę na mnie")
S("activate Orb power", "Küre gücünü aktif et")

S("pan up", "yukarı kaydır")
S("pan right", "sağa kaydır")
S("pan down", "aşağı kaydır")
S("pan left", "sola kaydır")
S("rotate left", "sola döndür")
S("rotate right", "sağa döndür")
S("home", "ortaya geri dön")

S("do nothing", "hiçbir şey yapma")
S("rotate view", "görüntüyü çevir")
S("panning X", "yatay kaydır")
S("panning Y", "dikey kaydır")
S("player 1 X", "oyuncu 1, yatay")
S("player 1 Y", "oyuncu 1, dikey")
S("player 1 go", "oyuncu 1, git")
S("player 1 spin", "oyuncu 1, dön")
S("player 2 X", "oyuncu 2, yatay")
S("player 2 Y", "oyuncu 2, dikey")
S("player 2 go", "oyuncu 2, git")
S("player 2 spin", "oyuncu 2, dön")

S("Joystick %1, axis %2", "Joystick %1, eksen %2")
S("one player", "tek kişilik")
S("two players", "iki kişilik")
S("configure player 1", "1. oyuncuyu ayarla")
S("configure player 2", "2. oyuncuyu ayarla")
S("configure panning", "kaydırmayı ayarla")
S("configure joystick axes", "joystick eksenlerini ayarla")
S("continue playing", "oyuna devam et")
S("start playing in the shmup mode", "SEMUP modunda oyun başlat")
S("return to the turn-based mode", "tur bazlı moda dön")
S("save the configuration", "ayarları kaydet")
S("press a key to unassign", "atamayı iptal için bir tuşa bas ")
S("press a key for '%1'", "'%1' için bir tuşa bas")
S("unassign a key", "bir tuş atamasını iptal et")

// extra pattern modes
// -------------------

S("explore the Emerald Pattern", "Zümrüt Dokusunu keşfet")
// S("explore the Fifty Pattern (4 colors)", "50 Dokuyu keşfet (4 renk)")
// S("explore the Fifty Pattern (8 colors)", "50 Dokuyu keşfet (8 renk)")

// extra flavor/Knight lines
// -------------------------

S("Kill a Vizier in the Palace to access Emerald Mine", "Zümrüt Madenine ulaşmak için Saray'da bir Vezir öldür.")
S("Collect 5 Emeralds to access Camelot", "Kamelot'a ulaşmak için 5 Zümrüt topla.")
S("Some lands unlock at specific treasures or kills", "Bazı diyarlara ulaşabilmek için belirli öldürmeler ve hazineler gerekebilir.")

S("You will be fighting red rock snakes, too...", "Kızıl yılanlarla da savaşacaksın...")

S("\"The Red Rock Valley is dangerous, but beautiful.\"",
  "\"KızılKaya Vadisi tehlikeli ama manzara çok güzel.\"")
S("\"Train in the Desert first!\"", "\"Önce Çöl'de kendini yetiştir!\"")
S("\"I like collecting ambers at the beach.\"", "\"Sahilde Kehribarlar toplamayı seviyorum.\"")
S("\"Our Table seats %1 Knights!\"", "\"Masamızda %1 Şövalye oturuyor!\"")
S("\"There are %1 floor tiles inside our Table!\"", "\"Masamızın içinde %1 zemin hücresi var!\"")
S("\"By now, you should have your own formula, you know?\"", "\"Şimdiye kadar kendi formülünü bulmalıydın değil mi?\"")
S("\"Have you tried to take a boat and go into the Ocean? Try it!\"", "\"Bir kayığa binip Okyanus'a açılmayı denedin mi? Denemelisin!\"")

// VERSION 7.3
// ===========

// CORRECTION:

N("closing plate", GEN_F, "kapatma levhası", "kapatma levhaları", "kapatma levhasını", "kapatma levhasıyla")
N("opening plate", GEN_F, "açma levhası", "açma levhaları", "açma levhasını", "açma levhasıyla")

// new name for 'Ivy D'

N("Dead Ivy", GEN_M, "Ölü Sarmaşık", "Ölü Sarmaşıklar", "Ölü Sarmaşığı", "Ölü Sarmaşıkla")

// new messages for living/nonliving monsters

S("%The1 bites %the2!", "%1 %a2 ısırdı!")
S("%The1 attacks %the2!", "%1 %2 tarafına saldırdı!")
S("You destroy %the1 with a mental blast!", "%a1 bir zihin patlamasıyla yok ettin!")
S("The ivy kills %the1!", "Sarmaşık %a1 öldürdü!")
S("You destroy %the1.", "%a1 yok ettin.")
S("%The1 kills %the2!", "%1 %a2 öldürdü!")
S("%The1 sinks!", "%1 battı!")

S("Cannot jump on %the1!", "%1 hücresine atlayamazsın!")

// renamed Fifty to Palace
S("explore the Palace Pattern (4 colors)", "Saray Dokusunu Keşfet (4 renk)")
S("explore the Palace Pattern (8 colors)", "Saray Dokusunu Keşfet (8 renk)")

// Map Editor
// ===========

S("map editor", "harita editörü")
S("You activate your terraforming powers!", "Yerdüzenleyici güçlerini harekete geçirdin!")
S("Press F5 to clear the board.", "Tahtayı temizlemek için F5'e bas")
S("Press F5 to restart the game normally.", "Oyunu normal başlatmak için F5'e bas")
S("High quality shots not available on this platform", "Yüksek kalite resimler bu platformda mevcut değil")
S("Saved the high quality shot to %1", "HQ resim %1 konumuna kaydedildi")
S("Map saved to %1", "Harita %1 konumuna kaydedildi")
S("Map loaded from %1", "Harita %1 konumundan yüklendi")
S("copying", "kopyalıyor")
S("boundary", "sınır")
S("clear monster", "canavarı temizle")
S("use at your own risk!", "sorumluluk sende!")

// Note: in English, these have been arranged from longest to shortest.
// This gives a somewhat nice effect on the top left corner of the screen.
// You may want to aim for the same effect when translating

S("0-9 = radius (%1)", "0-9 = promień (%1)")
S("b = boundary", "i = sınır")
S("m = monsters", "m = canavar")
S("w = walls",    "w = duvar")
S("i = items",    "l = eşya")
S("l = lands",    "c = diyar")
S("c = copy",     "b = kopya")

// And this is from shortest to longest (bottom left corner)
S("F1 = help",                "F1 = yardım")
S("F2 = save",                "F2 = kaydet")
S("F3 = load",                "F3 = yükle")
S("F5 = restart",             "F5 = yeniden başlat")
S("F6 = HQ shot",             "F6 = HQ resim çek")
S("F7 = player on/off",       "F7 = oyuncu açık/kapalı")
S("ESC = return to the game", "ESC = oyuna geri dön")

S(
  "This mode allows you to edit the map.\n\n"
  "NOTE: Use at your own risk. Combinations which never "
  "appear in the real game may work in an undefined way "
  "(do not work, look strangely, give strange messages, or crash the game).\n\n"
  "To get the most of this editor, "
  "some knowledge of inner workings of HyperRogue is required. "
  "Each cell has four main fields: land type, wall type, monster type, item type. "
  "The same wall type (especially \"none\", \"sea\", or \"bonfire\") may look or "
  "work a bit differently, based on the land it is in. Sometimes an object may "
  "appear twice on the list due to subtle differences (for example, Demons could "
  "move next turn or not).\n\n"
  "Press w, i, l, or m to choose which aspect of cells to change, "
  "then just click on the cells and they will change. Press 'c' while "
  "hovering over a cell to copy that cell, this copies all information about it. "
  "When copying large areas or placing multi-tile monsters, it might be important where "
  "on the cell you are clicking.\n\n"
  "You can also press 0-9 to apply your changes to a greater radius. "
  "This also affects the copy/paste feature, allowing to copy a larger area.\n\n"
  "Press F2 to save the current map (and F3 to load it). If you try this after "
  "a long game of HyperRogue (without using Orbs of Safety), the filesize will "
  "be very large! "
  "Note however that large structures, such as "
  "Great Walls, large circles and horocycles, are destroyed by this.\n\n"
  "Press 'b' to mark cells as boundaries. Such cells, and cells beyond "
  "them, are not copied by the copy/paste feature, nor saved by the "
  "save feature.\n\n",

  "Bu mod haritayı düzenlemeni sağlar..\n\n"
  "NOT: sorumluluk sende! Gerçek oyunda hiç karşına çıkmayacak kombinasyonlar "
  "bilinmeyen bir şekilde çalışabilir. (çalışmayabilir, garip gözükebilir, oyunu çökertebilir.).\n\n"
  "Editörü layığıyla kullanabilmek için HyperRogue'un iç dinamiklerine dair bilgi sahibi olman beklenir. "
  "Her hücre dört temel alana sahip: diyar tipi, duvar tipi, canavar tipi, eşya tipi."
  "Aynı duvar tipi (özellikle \"hiç\", \"deniz\", ve \"kampateşi\")"
  " içinde bulunduğu diyara göre farklı gözükebilir ve farklı işlev edinebilir. "
  "Bazen bir eşya özel durumundan ötürü listede iki kez gözükebilir."
  "(Meselâ şeytanın bir sonraki tur hareket edip edemeyeceği durumu).\n\n"
  "Hücrelerin hangi özelliğini değiştirmek istedğinizi w, i, l ve m'ye basarak seç. "
  "İşaretçinin olduğu hücreyi başka yere kopyalamak için c'ye bas. Bu, hücreye dair bilgiyi de kopyalar. "
  "Çok hücreli canavarları kopyalarken hücrenin neresine bastığın sonucu değiştirebilir.\n\n "
  "Değişikliklerini daha büyük bir çapta uygulamak için 0-9'a basabilirsin.. "
  "Bu aynı zamanda, kopyala/yapıştır özelliğinin de çapını genişletir.\n\n"
  "Mevcut haritayı kaydetmek için F2'ye bas (yüklemek için de F3'e bas). Eğer bunu Güvenlik Küresi kullanmadığınız bir oyunda denersen, "
  "dosya boyutu çok büyük olacaktır! Dikkat: Büyük yapılar, meselâ horosikıllar, büyük duvarlar, geniş çemberler bu özelliği kullanınca yok olurlar. \n\n"
  "Hücreleri sınır olarak belirlemek için b'ye basın. Bu hücreler ve bu hücrelerin ötesindeki hücreler, kopyala/yapıştır ve kaydetme özelliğine dahil edilmezler. \n\n"
  )

// Princess Quest
// ===============

// Saved the Princess - "Prensesi Kurtar" - "Prensesi kurtar."
// Princess Challenge - "Prenses Görevi- "Prenses Görevini tamamla."
// Martial Artist - "Dövüş Sporu" - "Silahsız bir Prensesin bir dövüşü kazanmasına yardım et."

S(
  "A mouse squeaks at you. It seems that it wants you to go somewhere. "
  "That's interesting, what could you find here?\n\n"
  "Note: in the part of the Palace that you are exploring during this "
  "quest, the distribution of monsters, pressure plates, and items has been "
  "changed somewhat, to make it a bit more suitable for less "
  "experienced players. The number of monsters does not depend on the "
  "number of Hypersian Rugs you have collected, and there are more "
  "opening plates.\n\n"
  "However, even with the normal distribution, it appears that it should be "
  "always possible to reach your goal. If you want this challenge, "
  "select it from the special game modes menu.",

  "Bir fare sana ciyakladı. Galiba senin bir yere gitmeni istiyor."
  "Gerçekten ilginç, burada ne bulabilirsin ki?\n\n"
  "W części Pałacu, którą zwiedzasz podczas tej misji, "
  "Not: Sarayın bu görev için hazırlanmış kısmında, canavarların dağılımı, baskı levhaları, ve eşyalar daha az deneyimli oyuncular düşünülerek bir nebze değiştirildi."
  "Canavar sayısı topladığın Aşkınlı Kilim sayısına bağlı değil ve burada daha çok açma levhası var. \n\n"
  "Yine de, normal dağılımla bile, bu görev her zaman tamamlanabilir. Eğer o görevi istiyorsan, özel oyun modları menüsünden onu seçebilirsin.")

S("\"When I visited the Palace, a mouse wanted me to go somewhere.\"",
  "\"Sarayı ziyaret ettiğimde, bir fare benden bir yere gitmemi istedi.\"")

S("\"I wonder what was there...\"", "\"Orada ne olduğunu merak ediyorum...\"")

N("Mouse", GEN_F, "Fare", "Fareler", "Fareyi", "Fareyle")

S("You hear a distant squeak!", "Uzaktan gelen bir ciyaklama duydun!")
S("%The1 squeaks in a confused way.", "%1 şaşkın bir şekilde ciyaklıyor.")
S("%The1 squeaks gratefully!", "%1 minnetle ciyaklıyor.")
S("%The1 squeaks hopelessly.", "%1 umutsuzca ciyaklıyor.")
S("%The1 squeaks in despair.", "%1 karamsarlıkla ciyaklıyor.")
S("%The1 squeaks sadly.", "%1 üzüntüyle ciyaklıyor.")
S("%The1 squeaks with hope!", "%1 umutla ciyaklıyor!")
S("%The1 squeaks happily!", "%1 neşeyle ciyaklıyor!")
S("%The1 squeaks excitedly!", "%1 heyecanla ciyaklıyor!")

N("giant rug", GEN_O, "devasa kilim", "devasa kilimler", "devasa kilimi", "devasa kilimle")

S("This is the biggest Hypersian Rug you have ever seen! "
  "Unfortunately, it is too large to take it as a trophy.",
  "Bu, gördüğün en büyük Aşkınlı Kilim! "
  "Maalesef yanında götüremeyeceğin kadar büyük.")

N("Prince", GEN_M, "Şehzade", "Şehzadeyi", "Şehzadeler", "Şehzadeyle")
N("Princess", GEN_F, "Prenses", "Prensesi", "Prensesler", "Prensesle")

S("%1 takes %his1 revenge on %the2!", "%1 intikamını alıyor!")
S("\"That should teach you to take me seriously!\"",
  "\"Bu sana beni ciddiye alman gerektiğini öğretir!\"")

S("%The1 kisses you, and begs you to bring %him1 away from here.",
  "%1 seni öpüyor ve sana %go1 buradan uzaklaştırman için yalvarıyor.")

S("\"I want my revenge. Stun a guard and leave him for me!\"",
  "İntikam istiyorum! Bir muhafızı sersemlet ve onu bana bırak!\"")

S("\"That felt great. Thanks!\"", "\"Çok iyi hissettim! Sağol!\"")

S("\"Bring me out of here please!\"", "Beni buradan çıkar lütfen!\"")

S("%The1 kisses you, and thanks you for saving %him1.",
  "%1 seni öptü ve %go1 kurtardığın için sana teşekkür etti.")

S("\"I have been trained to fight with a Hypersian scimitar, you know?\"",
  "Hiç Aşkınlı Palasıyla savaşmak üzere eğitilmemiştim biliyor musun?\"")

S("\"I would love to come to your world with you!\"",
  "Senle beraber dünyana gelmeyi çok isterdim!\"")

S("\"Straight lines stay close to each other forever, this is so romantic!\"",
  "\"Doğrular birbirlerine hep yakın, bu çok romantik!\"")

S("\"Maps... Just like the world, but smaller... how is that even possible?!\"",
  "\"Haritalar... Gerçek dünya gibi, ama daha küçük... bu nasıl mümkün olabilir?!\"")

Orb("Love", "Aşk")
S("Love takes time, but it heals all wounds, and transcends time and space.\n\n"
  "The Orb of Love is worth 30$$$, if you end the game with it.\n",

  "Aşk zaman alır, ama her yarayı iyileştirir ve zaman ve mekâna galip gelir.\n\n"
  "Aşk Küresi oyunu onunla bitirebilirsen 30$$$ eder.\n")

// Princess Challenge
// ------------------

S("%1 Challenge", "%1 Görevi")
S("Save %the1 first to unlock this challenge!", "Bu görevi açmak için önce %a1 kurtar!")
S("Welcome to %the1 Challenge!", "%1 görevine hoşgeldin!")
S("The more Hypersian Rugs you collect, the harder it is.", "Ne kadar Aşkınlı Kilim toplarsan o kadar zor.")
S("Follow the Mouse and escape with %the1!", "Fareyi takip et ve %abl1 kaç!")
S("Hardness frozen at %1.", "Trudność zamrożona: %1.")
S("Congratulations! Your score is %1.", "Tebrikler! Puanın: %1.")

S("u = undo",     "u = geri al")
S("Failed to save map to %1", "Harita %1 konumuna kaydedilemedi.")
S("Failed to load map from %1", "Harita %1 konumundan yüklenemedi")
S("other", "diğer") // other keys in the main menu
S("f = flip %1",     "f = çevir %1")
S("save whom", "kim kurtarılacak")

// VERSION 7.4
// ===========

// missing texts, refactored things, and rule changes
// --------------------------------------------------

S("%The1 activates her Flash spell!", "%1 Işık büyüsünü aktifleştirdi!")

N("Fire", GEN_O, "Ateş", "Ateşler", "Ateşi", "Ateşle")
S("This cell is on fire. Most beings and items cannot survive.",
  "Bu hücre yanıyor. Üzerindeki çoğu eşya ve canlı ölecek.")

N("Eternal Fire", GEN_O, "Sonsuz Ateş", "Sonsuz Ateşler", "Sonsuz Ateşi", "Sonsuz Ateşle")
S("This fire never burns out.", "Bu ateş hiç sönmüyor.")

S("Some rubble.", "Döküntüler.")

S("The Orb loses its power as it leaves the Land of Power!",
  "Küre Güç Diyarından ayrılırken gücünü kaybediyor!")

S("%The1 fills the hole!", "%1 deliği dolduruyor!")

N("Tentacle+Ghost", GEN_F, "Dokungaç&Hayalet", "Dokungaç&Hayaletler", "Dokungaç&Hayaleti", "Dokungaç&Hayaletle")

// Land Overview
// -------------

S("world overview", "dünya önizlemesi")
S("or 'o' to see the world overview", "veya dünya önizlemesini görmek için 'o'ya basın.")

S("forbidden to find in %the1", "%abl1 bulmak yasak.")
S("too dangerous to use in %the1", "zbyt niebezpieczna %abl1")
S("useless in %the1", "%abl1 işe yaramaz")
S("only native Orbs allowed in %the1", "%abl1 sadece oraya özgü Küreler kullanılabilir.")
S("this Orb is never unlocked globally (only hubs)", "bu Küre hiç tüm dünya için aktif edilmedi (sadece yerelde)")
S("collect 25 %2 to unlock it in %the1", "%abl1 onu aktif etmek için 25 tane %2 topla.")
S("collect 3 %2 to unlock it in %the1", "%abl1 onu aktif etmek için 3 tane %2 topla.")
S("native to %the1 (collect 10 %2)", "%abl1 bulunuyor (10 tane %2)")
S("native to %the1 (collect 1 %2)", "%abl1 bulunuyor (1 tane %2)")
S("secondary in %the1 (collect 10 %3, or 25 %2)", "%abl1 ikincil olarak bulunuyor (10 tane %3, veya 25 tane %2)")
S("the native Orb of %the1", "%abl1 doğal olarak bulunan Küre")
S("this Orb appears on floors and is used by witches", "Bu Küre zeminlerde bulunur ve cadılarca kullanılır.")
S("a prized Orb, it appears only in cabinets", "çok kıymetli bir Küre, sadece vitrinde bulunur.")
S("this Orb never appears in %the1", "Bu Küre %abl1 hiç bulunmaz")
S("Hub Land: orbs appear here if unlocked in their native land", "Merkez: Ana diyarında aktifleştirilen küreler burada gözükür.")
S("kill a monster, or collect 25 %2", "bir canavar öldür, ya da 25 tane %2 topla.")

S("Always available.\n", "Her zaman mevcut.\n")
S("Treasure required: %1 $$$.\n", "Hazine gerekiyor: %1 $$$.\n")
S("Accessible only from %the1.\n", "Sadece %a1 erişilebilir.\n")
S("Accessible only from %the1 (until finished).\n", "Sadece %a1 erişilebilir. %a1 (bitirilene kadar).\n")

S("Accessible only from %the1 or %the2.\n", "Sadece %a1 veya %a2 erişilebilir.\n")

S("Kills required: %1.\n", "Gereken leşler: %1 $$$.\n")
S("Finished lands required: %1 (collect %2 treasure)\n",
  "Gereken bitirilmiş diyarlar: %1 (%2 hazine toplananlar)\n")

S("Treasure required: %1 x %2.\n", "Gereken hazine: %1 tane %2.\n")

S("Alternatively: kill a %1.\n", "Ya da: Bir %1 öldür.\n")

S("Kills required: any Elemental (Living Fjord/Dead Caves).\n",
  "Gereken leşler: Herhangi bir Özüt (Yaşayan Fiyort/Ölü Mağaralar).")

S("Variants of %the1 are always available in the Random Pattern Mode.",
  "%1 çeşitlemeleri Rastgele Doku Modunda her zaman mevcuttur.")

S("Variants of %the1 are available in the Random Pattern Mode after "
  "getting a highscore of at least 10 %2.",
  "%1 çeşitlemeleri Rastgele Doku Modunda en az on tane %2 skoru elde ederek açılır. ")

S(" kills: %1", " leşler: %1")
S(" $$$: %1", " $$$: %1")
S(" Hyperstone: %1/%2", " Aşkıntaş: %1/%2")
S(" Hell: %1/%2", " Cehennem: %1/%2")

// improved editor
// ---------------

S("vector graphics editor -- press F1 for help", "vektör grafik editörü -- yardım için F1'e bas.")
S("pics to save/load:", "kaydedilecek/yüklenecek resimler")
S("level to save/load:", "kaydedilecek/yüklenecek bölüm")

S("F4 = extension", "F4 = genişletme")
S("Enter = back", "Enter = geri")
S("SPACE = map/graphics", "SPACE = harita/grafikler")

S("Emerald Pattern", "Zümrüt Dokusu")
S("Palace Pattern", "Saray Dokusu")
S("Zebra Pattern", "Zebra Dokusu")
S("rotational symmetry", "döngüsel simetri")
S("symmetry 0-1", "simetri 0-1")
S("symmetry 0-2", "simetri 0-2")
S("symmetry 0-3", "simetri 0-3")

S("display pattern codes (full)", "doku kodlarını göster (tam)")
S("display pattern codes (simplified)", "doku kodlarını göster (basitleştirilmiş)")
S("display only hexagons", "sadece altıgenleri göster")
S("display only heptagons", "sadece yedigenleri göster")
S("predesigned patterns", "hazır dokular")

S("Gameboard", "Oyun Tahtası")
S("random colors", "rastgele renkler")
S("emerald pattern", "zümrüt dokusu")
S("four elements", "dört element")
S("eight domains", "sekiz alan")
S("zebra pattern", "zebra dokusu")
S("three stripes", "üç şerit")
S("random black-and-white", "rastgle siyah-beyaz")
S("p = paint", "p = boya")
S("r = regular", "r = düzenli")

S(
   "In this mode you can draw your own player characters, "
   "floors, monsters, and items. Press 'e' while hovering over "
   "an object to edit it. Start drawing shapes with 'n', and "
   "add extra vertices with 'a'. Press 0-9 to draw symmetric "
   "pictures easily. More complex pictures can "
   "be created by using several layers ('l'). See the edges of "
   "the screen for more keys.",

   "Bu modda kendi karakterlerini, zeminlerini, canavarlarını ve eşyalarını çizebilirsin. İşaretçiyi bir nesneye götür ve onu düzenlemek için 'e'ye bas. "
   "'n' ile şekiller çizmeye başlayabilir, 'a' ile yeni köşeler ekleyebilirsin. 0-9'a basarak simetrik resimleri daha kolay çizebilirsin. "
   "Daha karmaşık resimler için birden fazla atman gerekebilir ('l'). Ekranın kıyılarına bakara daha fazla tuşu öğrenebilirsin."
   )

S(
   "Press 'r' to choose a regular pattern. When a pattern is on, "
   "editing a cell automatically edits all cells which are "
   "equivalent according to this pattern. You can choose from "
   "several patterns, and choose which symmetries matter "
   "for equivalence. Also, you can press Space to switch between "
   "the map and graphics editor quickly -- note that editing floors "
   "with the graphics editor also adheres to the pattern.",

   "'r'ye basarak düzenli bir doku seçebilirsin. Bir doku aktifken, bir hücreyi değiştirmek o hücreye bu dokuda eşdeğer bütün hücreleri de değiştirir."
   " Birden çok doku seçebilirsin ve hangi simetrilerin eşdeğer olduğunu seçebilirsin. Ayrıca, Space'e basarak harita ve grafik editörü arasında hızlıca gidip gelebilirsin -- "
   "zeminin grafik editörüyle değiştirilmesinin dokuyu da değiştireceğini unutma.")

S("monster" ,"canavar")
S("item", "eşya")
S("floor", "zemin")
S("hexagonal", "altıgensel")
S("heptagonal", "yedigensel")
S("floor/pattern", "zemin/doku")

S("l = layers: %1", "l = katmanlar: %1")
S("1-9 = rotations: %1", "1-9 = döndürmeler %1")
S("0 = symmetry", "0 = simetri")
S("0 = asymmetry", "0 = asimetri")
S("%1 vertices", "köşeler: %1")
S("a = add v", "a = ekle v")
S("m = move v", "m = taşı v")
S("d = delete v", "d = sil v")
S("c = readd v", "c = yeniden ekle v")
S("b = reorder", "b = yeniden sırala")
S("t = shift", "t = kaydır")
S("y = spin", "y = döndür")

S("'n' to start", "n = başlat")
S("z = zoom in", "z = yaklaş")
S("o = zoom out", "o = uzaklaş")
S("g = grid", "g = şablon")
S("e = edit this", "e = bunu düzenle")

S("x: %1", "x: %1")
S("y: %1", "y: %1")
S("z: %1", "z: %1")
S("r: %1", "r: %1")
S("ϕ: %1°", "ϕ: %1°")

S("A fake Land with colored floors.",
  "Renkli zeminli bir sahte diyar.")

S("random pattern mode", "rastgele doku modu")

// Ivory Tower
// -----------

N("Ivory Tower", GEN_F, "Fildişi Kule", "Fildişi Kuleler", "Fildişi Kuleyi", "Fildişi Kulede")

S(
  "Powerful wizards claimed this part of the world, to perform their magical "
  "experiments in peace and solitude. They have changed the direction of gravity, "
  "to make it even harder for intruders to reach them.\n\n"
  "Gravity works as follows: cells are unstable if they are empty, and there is "
  "no cell immediately below them which contains a wall. It is impossible to move "
  "from one unstable cell to another, except if moving down.",

  "Güçlü büyücüler, dünyanın bu kısmını, büyüsel deneylerini sessiz sakin uygulayabilecekleri yer olarak seçtiler. Davetsiz misafirlerin, onlara ulaşabilmesini daha zor kılmak için yerçekiminin yönünü değiştirdiler.\n\n"
  "Yerçekimi şu şekilde çalışır: Hücreler eğer boşlar ise dengesiz haldedirler ve hücrelerin hemen altında bulunan bir duvar yoktur. Bir dengesiz hücreden diğerine ilerlemek imkansızdır, aşağı doğru ilerlemek hariç.\n\n"

  )

N("Servant", GEN_M, "Hizmetkâr", "Hizmetkârlar", "Hizmetkârı", "Hizmetkârla")
S("A simple servant of the master of the Ivory Tower.",
  "Fildişi Kuledeki basit bir hizmetkâr.")

N("Gargoyle", GEN_M, "Çörten", "Çörtenler", "Çörteni", "Çörtenle")
N("stone gargoyle", GEN_M, "taş çörten", "taş çörtenler", "taş çörteni", "taş çörtenle")
N("stone gargoyle floor", GEN_F, "taş çörten zemini", "taş çörten zeminleri", "taş çörten zeminini", "taş çörten zeminiyle")
N("stone gargoyle bridge", GEN_O, "taş çörten köprüsü", "taş çörten köprüleri", "taş çörten köprüsünü", "taş çörten köprüsüyle")

S(
  "A being made of stone, who likes high buildings. It becomes normal stone when "
  "killed, but only if next to something stable -- otherwise it falls.",
  "Yüksek binaları seven taştan yapılmış bir yaratık. Öldürüldüğünde eğer durağan bir şeyin yanındaysa normal taş haline gelir, yoksa düşer.")

N("Ivory Figurine", GEN_F, "Fildişi Biblo", "Fildişi Biblolar", "Fildişi Bibloyu", "Fildişi Bibloyla")

S("A beautiful figurine, made of ivory. Figurines close to the base of the Tower "
  "tend to disappear after you have collected many of them.",
  "Fildişinden yapılmış güzel bir biblo. Bunlardan çok sayıda topladığında, kulenin temeline yakın biblolar yok olmaya başlar.")

N("Platform", GEN_F, "Platform", "Platformlar", "Platformu", "Platformla")
S("You can stand here.", "Burada durabilirsin.")

N("ladder", GEN_F, "merdiven", "merdivenler", "merdiveni", "merdivenle")
S("You can use this ladder to climb the Tower.",
  "Kuleye çıkmak için bu merdiveni kullanabilirsin.")

Orb("Matter", "Madde")

S("This Orb allows one to temporarily create impassable matter, either to block paths or "
  "to build bridges across chasms and waters.",
  "Bu Küre, yolları tıkamak veya boşluklar ve su üzerine köprü kurmak için geçilemez madde oluşturmaya yarar. ")

N("temporary wall", GEN_F, "geçici duvar", "geçici duvarlar", "geçici duvarı", "geçici duvarla")
N("temporary floor", GEN_F, "geçici zemin", "geçici zeminler", "geçici zemini", "geçici zeminle")
N("temporary bridge", GEN_O, "geçici köprü", "geçici köprüler", "geçici köprüyü", "geçici köprüyle")

S("This structure will disappear after some time.", "Bu yapı bir süre sonra yok olacak.")

S("Nothing to stand on here!", "Burada duracağın bir şey yok!")
S("Gravity does not allow this!", "Yerçekimi buna izin vermiyor!")

// Elemental Planes
// ----------------

N("Elemental Planes", GEN_F, "Unsur Düzlemleri", "Unsur Düzlemleri", "Unsur Düzlemlerini", "Unsur Düzlemlerinde")
N("Plane of Fire", GEN_F, "Ateş Düzlemi", "Ateş Düzlemleri", "Ateş Düzlemini", "Ateş Düzleminde")
N("Plane of Earth", GEN_F, "Toprak Düzlemi", "Toprak Düzlemleri", "Toprak Düzlemini", "Toprak Düzleminde")
N("Plane of Air", GEN_F, "Ateş Düzlemi", "Ateş Düzlemleri", "Hava Düzlemini", "Hava Düzleminde")
N("Plane of Water", GEN_F, "Su Düzlemi", "Su Düzlemleri", "Su Düzlemini", "Su Düzleminde")

S("The Elemental Planes are divided into four subzones: Planes of Fire, Water, Air, and Earth. "
  "You need to collect a Shard from each Plane to construct an Elemental Gem. "
  "It is dangerous to collect too many Shards of the same type without constructing a Gem.",

  "Unsur Düzlemleri dört altalana ayrılır: Ateş, Su, Hava ve Toprak Düzlemleri. Bir Unsurtaşı yapmak için her dört düzlemden birer parça toplaman gerekiyor. "
"Bir Unsurtaşı yapmadan aynı cins parçadan çok sayıda toplamak tehlikelidir."
  )

N("Fire Elemental", GEN_M, "Ateş Unsuru", "Ateş Unsurları", "Ateş Unsurunu", "Ateş Unsuruyla")

S("This monster leaves a trail of fire behind.",
  "Bu canavar arkasında ateşten bir iz bırakıyor.")

N("Air Elemental", GEN_M, "Hava Unsuru", "Hava Unsurları", "Hava Unsurunu", "Hava Unsuruyla")

S("An Air Elemental looks like a live tornado. Once you are three (or less) cells from it, "
  "it is impossible to move closer, due to strong winds. You can stand and wait, though. "
  "This also affects most monsters.",

  "Hava Unsuru canlı bir hortuma benziyor. Eğer ondan üç ya da daha az uzaklıktaysan, güçlü rüzgârlardan ötürü daha fazla yakınlaşman mümkün değildir. Geçip gitmesini bekleyebilirsin elbette. Bu çoğu canavarı da etkiler. ")

N("Fire Shard", GEN_M, "Ateş Parçası", "Ateş Parçaları", "Ateş Parçasını", "Ateş Parçasıyla")
N("Air Shard", GEN_M, "Hava Parçası", "Hava Parçaları", "Hava Parçasını", "Hava Parçasıyla")
N("Water Shard", GEN_M, "Su Parçası", "Su Parçaları", "Su Parçasını", "Su Parçasıyla")
N("Earth Shard", GEN_M, "Toprak Parçası", "Toprak Parçaları", "Toprak Parçasını", "Toprak Parçasıyla")
N("Elemental Gem", GEN_M, "Unsurtaşı", "Unsurtaşları", "Unsurtaşını", "Unsurtaşıyla")

Orb("Summoning", "Çağırma")

S(
    "This orb allows you to summon monsters. Usually, they are either Elementals or "
    "native creatures. While the monsters do not like being summoned, and will "
    "attack you once they recover from summoning sickness, such summoning "
    "often has its uses.",
  "Bu küre canavar çağırabilmeni sağlar. Genelde Özütler veya yerel canavarlar çağrılır."
"Canavarlar çağrılmaktan hoşlanmasalar ve çağrılma hastalıkları biter bitmez sana saldıracak olsalar da, yine de çağırmanın işe yaradığı yerler olabilir."
  )

N("limestone wall", GEN_F, "kireçtaşı duvar", "kireçtaşı duvarlar", "kireçtaşı duvarı", "kireçtaşı duvarla")

S("Simply a wall. Mostly.", "Yalnızca bir duvar. Büyük ihtimalle.")

// Zebra
// -----

N("Zebra", GEN_F, "Zebra", "Zebralar", "Zebrayı", "Zebrada")
S("Everything in this Land has black and white stripes.",
  "Bu diyardaki her şey siyah ve beyaz şeritlere sahip.")

N("Striped Dog", GEN_M, "Şeritli Köpek", "Şeritli Köpekler", "Şeritli Köpeği", "Şeritli Köpekle")
S("A predator native to the Zebra.", "Zebra'da yaşayan bir vahşi hayvan.")

N("Onyx", GEN_O, "Akik", "Akikler", "Akiği", "Akikle")
S("A black gem with white stripes. It is beautiful.", "Beyaz şeritli siyah bir mücevher. Çok güzel.")

// Crossroads III
// --------------

N("Crossroads III", GEN_N, "Arayollar III", "Arayollar III", "Arayolları III", "Arayollarda III")

S("An alternate layout of the Crossroads. Great Walls cross here at right angles.",
  "Arayollar için bir alternatif düzen. Büyük Duvarlar burada dik açı yaparak kesişir.")

// Steam achievements:

/*
		"NEW_ACHIEVEMENT_5_12_NAME"	"Fildişi Kule'ye ulaş"
		"NEW_ACHIEVEMENT_5_12_DESC"	"Bir Fildişi Biblo bul ve topla."
		"NEW_ACHIEVEMENT_5_13_NAME"	"Hizmetkâr"
		"NEW_ACHIEVEMENT_5_13_DESC"	"10 Fildişi Biblo topla."
		"NEW_ACHIEVEMENT_5_14_NAME"	"Çörten"
		"NEW_ACHIEVEMENT_5_14_DESC"	"25 Fildişi Biblo topla."
		"NEW_ACHIEVEMENT_5_15_NAME"	"Kule Efendisi"
		"NEW_ACHIEVEMENT_5_15_DESC"	"50 Fildişi Biblo topla."
		"NEW_ACHIEVEMENT_5_16_NAME"	"Zebra'ya Ulaş"
		"NEW_ACHIEVEMENT_5_16_DESC"	"Bir Akik bul ve topla."
		"NEW_ACHIEVEMENT_5_17_NAME"	"Çizgili Köpek"
		"NEW_ACHIEVEMENT_5_17_DESC"	"10 Akik Topla."
		"NEW_ACHIEVEMENT_5_18_NAME"	"Benekli Köpek"
		"NEW_ACHIEVEMENT_5_18_DESC"	"25 Akik Topla."
		"NEW_ACHIEVEMENT_5_19_NAME"	"Damalı Köpek"
		"NEW_ACHIEVEMENT_5_19_DESC"	"50 Akik Topla."
		"NEW_ACHIEVEMENT_5_20_NAME"	"Unsurcu"
		"NEW_ACHIEVEMENT_5_20_DESC"	"Bir Unsurtaşı oluştur."
		"NEW_ACHIEVEMENT_5_21_NAME"	"İkincil Unsur"
		"NEW_ACHIEVEMENT_5_21_DESC"	"10 Unsurtaşı oluştur."
		"NEW_ACHIEVEMENT_5_22_NAME"	"Esas Unsur"
		"NEW_ACHIEVEMENT_5_22_DESC"	"25 Unsurtaşı oluştur."
		"NEW_ACHIEVEMENT_5_23_NAME"	"Elementlerin Efendisi"
		"NEW_ACHIEVEMENT_5_23_DESC"	"50 Unsurtaşı oluştur."
*/

S("Cannot create temporary matter on a monster!", "Geçici maddenin üzerinde bir canavar çıkaramazsın!")
S("Cannot create temporary matter on an item!", "Bir eşyanın üzerinde geçici madde oluşturamazsın!")
S("Cannot create temporary matter here!", "Burada geçici madde oluşturamazsın!")
S("Cannot summon on a monster!", "Bir canavarın üstüne çağıramazsın!")
S("No summoning possible here!", "Çağırmak burada mümkün değil!")
S("You summon %the1!", "%a1 çağırdın!")

S("F4 = file", "F4 = dosya")

// CORRECTION FOR ELEMENTALS

N("Earth Elemental", GEN_M, "Toprak Unsuru", "Toprak Unsurları", "Toprak Unsurunu", "Toprak Unsuruyla")
N("Water Elemental", GEN_M, "Su Unsuru", "Su Unsurları", "Su Unsurunu", "Su Unsuruyla")
S("Wherever this powerful being goes, the living fjord "
  "sinks below water, non-magical boats are destroyed, and fires are extinguished.\n\n"
  "As a special case, you can attack the Water Elemental from the water, without drowning immediately.",
  "Bu güçlü yaratığın geçtiği her yerde Yaşayan Fiyort su altına gömülür, sihirli olmayan kayıklar yok olur ve ateşler söner. \n\n "
  "İstisna bir durum olarak Su Unsuruna suyun içerisinden anında boğulmadan vurursan onu öldürebilirsin. ")
S("A coastal area, from where you can get both to the inland worlds and to the Ocean. "
  "Each turn, each cell will become water or earth, based on the majority of cells around it. "
  "Contrary to the Living Caves, this process is not affected by most items and monsters, "
  "but elementals, dead Trolls, and cells outside of the Living Fjord have "
  "a very powerful effect.",
  "Sahil şeridinde bir bölge, buradan hem iç diyarlara hem de Okyanus'a geçebilirsin. "
  "Her tur, her hücre etrafındaki hücrelerin çoğunluğuna göre su veya toprak olacak. "
  "Yaşayan Mağaraların aksine, bu süreç eşyalar veya canavarlardan etkilenmez. "
  "Ancak Yaşayan Fiyortların dışındaki hücreler, Unsurlar ve Ölü Trollerin etkisi çok güçlüdür."
  )

// S("TRANSLATIONWARNING", "Uyarı: Türkçe çeviri henüz Sürüm 8.0' daki yeni özellikleri kapsamıyor.")
// S("TRANSLATIONWARNING", "")



// Also, as the game is constantly updated, the Steam version includes the newest features, such as new lands with new mechanics, or new game modes -- see [ http://www.roguetemple.com/z/hyper/gallery.php]Gallery[/url] for the current differences.

// CORRECTION:
N("great wall", GEN_F, "Yüksek Duvar", "Yüksek Duvarlar", "Yüksek Duvarı", "Yüksek Duvarda")

// VERSION 8.0
// ============

S("The Air Elemental blows you away!", "Hava Unsuru seni uzağa uçuruyor!")

// appended to cave troll description
S(" Additionally, all items around the killed Troll will be destroyed.",
  " Ayrıca, Trolün etrafındaki bütün eşyalar yok olur.")

// 'dead cave troll' and 'dead troll' are separated now

N("dead rock troll", GEN_M, "ölü mağara trolü" ,"ölü mağara trolleri", "ölü mağara trolünü", "ölü mağara trolüyle")

S("There are several species of trolls living in the hyperbolic world. "
  "Some of them leave this wall behind them when they die.",

  "Hiperbolik dünyada pek çok tür trol yaşar."
  "Bazıları öldüğünde bu duvarı geride bırakır.")

// paper model creator
// --------------------

S("paper model creator", "kâğıt modeli üreticisi")
S("synchronize net and map", "haritayı ve ağı eşle")
S("display the scope", "odağı göster")
S("create the model", "modeli üret")
S("design the net", "ağı tasarla")

S("The paper model created as papermodel-*.bmp", "Kâğıt model papermodel-*.bmp şeklinde üretildi")
S("Failed to load the file 'papermodeldata.txt'", "papermodeldata.txt dosyası yüklenemedi")
S("Could not save the paper model data", "Kâğıt modeli verisi kaydedilemedi")

// pure tactics mode
// ------------------

S("pure tactics mode", "saf taktik modu")
S("Not available in the pure tactics mode!", "Taktik modunda kullanılamaz!")
S("\"The Knights of the Horocyclic Table salute you!\"", "\"Horosikıl Masa Şövalyeleri seni selamlıyor!\"")
S("press 0 to leave this mode", "Bu moddan çıkmak için 0'a bas")
S("Collect %1x %2 to unlock", " %1 tane %2 toplayarak aktifleştir")

S(
        "In the pure tactics mode, you concentrate on a specific land. "
        "Your goal to obtain as high score as possible, without using "
        "features of the other lands. You can then compare your score "
        "with your friends!\n\n"

        "You need to be somewhat proficient in the normal game to "
        "unlock the given land in this challenge "
        "(collect 20 treasure in the given land, or 2 in case of Camelot).\n\n"

        "Since getting high scores in some lands is somewhat luck dependent, "
        "you play each land N times, and your score is based on N consecutive "
        "plays. The value of N depends on how 'fast' the land is to play, and "
        "how random it is.\n\n"

        "In the Caribbean, you can access Orbs of Thorns, Aether, and "
        "Space if you have ever collected 25 treasure in their native lands.\n\n"

        "The rate of treasure spawn is static in this mode. It is not "
        "increased by killing monsters.\n\n"

        "Good luck, and have fun!",

        "Saf taktik modunda sadece tek bir diyara odaklanırsın. Amacın diğer diyarların özelliklerini hiç kullanmadan mümkün olduğunca yüksek puan yapmak. Sonra skorunu arkadaşlarınınkiyle karşılaştırabilirsin!\n\n "

        "Normal oyunda maharetini ispatlayarak belli bir diyarı bu modda açabilirsin. "
        "(Belli bir diyarda 20 hazine toplamak, Kamelot için 2 hazine toplamak gibi).\n\n"

        "Yüksek skor almak şöyle böyle şansa bağlı olduğundan, her diyarı N defa oynarsın ve skorun bu ardarda N oyuna göre belirlenir. N'in değeri diyarın ne kadar hızlı oynandığına ve ne derece rassal olduğuna göre değişir.\n\n"

        "Karayiplerde, Diken Küresine, Ether'e ve Uzay'a eğer daha önce ilgili diyarlarda 25'er hazine topladıysan erişebilirsin.\n\n"

        "Hazine üretimi bu modda statiktir ve canavar öldürmekle artmaz.\n\n"

        "İyi şanslar ve iyi eğlenceler!")

// Yendor Challenge
// -----------------

S("Yendor Challenge", "Yendor Ek Görevi")
//Görev?
S("Collect 10 treasures in various lands to unlock the challenges there",
  "Çeşitli diyarlarda 10 hazine toplayarak o diyarın özel görevini aktifleştirebilirsin")

S("easy", "kolay")
S("challenge", " ek görev")

S("Challenges do not get harder", "Ek görevler zorlaşmaz.")
S("Each challenge gets harder after each victory", "Her zaferinden sonra ek görevler zorlaşır.")

S(" (won!)", " (kazandın!)")
S(" (won at level %1!)", " (%1. seviyede kazandın!)")
S("(locked)", "(aktif değil)")

S(
    "There are many possible solutions to the Yendor Quest. In the Yendor "
    "Challenge, you will try many of them!\n\n"
    "Each challenge takes part in a specific land, and you have to use what "
    "you have available.\n\n"

    "You need to obtain an Orb of Yendor in the normal game to activate "
    "this challenge, and (ever) collect 10 treasures in one or two lands "
    "to activate a specific level.\n\n"

    "After you complete each challenge, you can try it again, on a harder "
    "difficulty level.\n\n"

    "All the solutions showcased in the Yendor Challenge work in the normal "
    "play too. However, passages to other lands, and (sometimes) some land features "
    "are disabled in the Yendor "
    "Challenge, so that you have to use the expected method. Also, "
    "the generation rules are changed slightly for the Palace "
    "and Minefield while you are looking for the Orb of Yendor, "
    "to make the challenge more balanced "
    "(but these changes are also active during the normal Yendor Quest).\n\n"

    "You get 1000 points for each challenge won, and 1 extra point for "
    "each extra difficulty level.",

    "Yendor Görevinin bir sürü çözümü var. Yendor Ek Görevi'nde bunların pek çoğunu deneyeceksin!\n\n"
    "Her görev belirli bir diyarda geçiyor ve elindekileri bütün verimliliğiyle kullanman gerekecek.\n\n"
    "Bu görevi aktifleştirmek için normal oyunda bir kez Yendor'un Küresi'ni ele geçirmen gerekiyor. Ayrıca her hangi bir seviyeyi aktifleştirmek için ilgili diyar(lar)da 10 hazine toplamış olman gerekiyor.\n\n"

    "Ek görevi tamamladıktan sonra aynı görevi bir üst zorluk seviyesinde yeniden deneyebilirsin.\n\n"

    "Yendor Ek Görevi'ndeki bütün çözümler normal oyunda da işe yarar. Ancak, Yendor Ek görevinde, diğer diyarlara geçiş ve bazen diyarın bazı özellikleri devredışıdır, bu yüzden beklenen çözümü bulman beklenir. "
    "Ayrıca,  Yendor'un Küresi'ni ararken görevin daha dengeli olması için Saray ve Mayın Tarlasındaki harita üretimi biraz değiştirilmiştir. (bu değişiklikler normal Yendor Görevi'nde de mevcuttur).\n\n"
    "Her kazanılan ek görev için 1000 puan ve her fazladan zorluk seviyesi için 1 fazladan puan kazanırsın.\n\n"
    )

S("Unlock this challenge by getting the Orb of Yendor!",
  "Yendor'un Küresi'ni alarak bu ek görevi aktif et!")

S("Collect 10 treasures in various lands to unlock the challenges there",
  "Diyarlardaki ek görevleri aktif etmek için oralarda 10 hazine topla.")

// Wild West
// ----------

N("Wild West", GEN_O, "Vahşi Batı", "Vahşi Batılar", "Vahşi Batıyı", "Vahşi Batıda")
N("Outlaw", GEN_M, "Haydut" ,"Haydutlar", "Haydutu", "Haydutla")
N("Bounty", GEN_F, "Ödül", "Ödüller", "Ödülü", "Ödülle")
N("saloon wall", GEN_F, "bar duvarı", "bar duvarları", "bar duvarını", "bar duvarıyla")
N("Revolver", GEN_O, "Altıpatlar", "Altıpatlarlar", "Altıpatları", "Altıpatlarla")

S("%The1 shoots you!", "%1 sana ateş etti!")
S("You shoot %the1!", "%1 düşmanına ateş ettin!")

S(
  "Take a revolver, kill outlaws, collect bounties.\n\n"
  "Note: since this land is anachronistic, it is not available in normal game. "
  "It is only available in special modes.",

  "Altıpatları al, haydutları öldür, başlarına konan ödülleri topla!\n\n"
  "Not: Bu diyar anakronistik olduğu için, normal oyunda mevcut değil, sadece özel modlarda oynanabilir.")

// Land of Storms
// ---------------

S(
  "Whenever after your move there is a connection between a charged and a "
  "grounded cell, there is a short circuit. All cells on any "
  "path connecting a charged and a grounded cell (without repeated cells, "
  "or two consecutive grounded/charged cells) become damaged.\n\n"

  "Sandstone walls and most creatures are conductive. Great Walls are "
  "isolators, but lands beyond them count as grounded.\n\n"

  "Fulgurite, the treasure, is created when you manage to short circuit "
  "a sandstone wall, or a Rich Metal Beast.\n\n"

  "Trolls leave conductive rocks when killed, and Metal Beasts can only "
  "be killed by electricity -- your attacks only stun them, or push "
  "them away if already stunned.",

  "Hareketinden sonra, eğer yüklü ve topraklı bir hücre arasında bağlantı varsa, kısa devre olur."
  "Yüklü ve topraklı hücrenin arasındaki bütün hücreler (tekrarlayan hücreler, yahut iki ardışık topraklı yahut yüklü hücre hariç) hasar görür.\n\n"

  "Kumtaşı duvarları ve çoğu yaratık iletkendir. Büyük Duvarlar yalıtkandır, ancak onlardan sonraki hücreler topraklanmış sayılır. \n\n"

  "Fulgurit, buradaki hazine, bir kumtaşı duvarını veya Zengin Metal Canavarını kısa devreye uğratmanla ortaya çıkar.\n\n"

  "Troller öldüklerinde artlarında iletken kayalar bırakırlar ve Metal Canavarlar sadece elektrik ile öldürülebilirler. Saldırıların metal canavarları sersemletir, yahut zaten sersemlemişlerse ittirir. ")


N("Land of Storms", GEN_F, "Fırtına Diyarı", "Fırtına Diyarları", "Fırtına Diyarını", "Fırtına Diyarında")
N("charged wall", GEN_F, "yüklü duvar", "yüklü duvarlar", "yüklü duvarı", "yüklü duvarla")
N("grounded wall", GEN_F, "topraklı duvar", "topraklı duvarlar", "topraklı duvarı", "topraklı duvarla")
N("metal wall", GEN_F, "metal duvar", "metal duvarlar", "metal duvarı", "metal duvarla")
N("sandstone wall", GEN_F, "kumtaşı duvarı", "kumtaşı duvarları", "kumtaşı duvarını", "kumtaşı duvarla")
N("Storm Troll", GEN_M, "Fırtına Trolü", "Fırtına Trolleri", "Fırtına Trolünü", "Fırtına Trolüyle")
N("Metal Beast", GEN_O, "Metal Canavar", "Metal Canavarları", "Metal Canavarını", "Metal Canavarıyla")
N("Rich Metal Beast", GEN_O, "Zengin Metal Canavar", "Zengin Metal Canavarları", "Zengin Metal Canavarını", "Zengin Metal Canavarıyla")
N("electric discharge", GEN_N, "elektrik boşalımı", "elektrik boşalımları", "elektrik boşalımını", "elektrik boşalımıyla")

S("There is a flash of thunder!", "Bir şimşek çaktı!")

Orb("Stunning", "Sersemletme")

S("This Orb allows you to target monsters to stun them. "
  "10 charges are used to stun for 5 turns. Does not "
  "work against multi-tile monsters.",

  "Bu Küre canavarları hedefleyerek sersemletmeni sağlar. 5 tur sersemletmek için 10 güç kullanır. Çokluhücre canavarlara karşı çalışmaz."
  )

S("You stun %the1!", "%a1! sersemlettin!")

// Overgrown Woods
// ----------------

Orb("Luck", "Şans")

S("This Orb allows you to find new lands more easily. "
  "Lands where you have already collected less treasure, "
  "and especially the Crossroads, are more likely to "
  "spawn while you have this. Additionally, Orbs of Safety "
  "are more likely to spawn in the Whirlpool.",

  "Bu küre yeni diyarlar bulmanı kolaylaştırır. Daha az hazine topladığın diyarlar ve özellikle Arayollar, bu küreyi elinde tutarken daha yüksek ihtimalle karşına çıkar. "
  "Ayrıca, Güvenlik Kürelerinin Tayfun'da ortaya çıkma ihtimalini artırır."
  )

N("Overgrown Woods", GEN_O, "Azman Orman", "Azman Ormanlar", "Azman Ormanı", "Azman Ormanda")
N("Mutant Ivy", GEN_O, "Mutant Sarmaşık", "Mutant Sarmaşıklar", "Mutant Sarmaşığı", "Mutant Sarmaşıkla")
N("Mutant Sapling", GEN_F, "Mutant Fidan", "Mutant Fidanlar", "Mutant Fidanı", "Mutant Fidanla")
N("Forest Troll", GEN_M, "Orman Trolü", "Orman Trolleri", "Orman Trolünü", "Orman Trolüyle")

S("Forest Trolls create an impassable wall when they die.",
  "Orman Trolleri öldüklerinde artlarında aşılmaz bir duvar bırakır.")

S(
  "The Overgrown Woods are filled with mutant ivies! These plants "
  "grow very fast. Each leaf, after being grown, can grow itself "
  "on the next turn. However, each part is only able to grow "
  "once in 16 turns. Outside of the Overgrown Woods, the Mutant Ivy "
  "may grow only on hexagonal cells.\n\n"
  "Maybe such fast growing plants could help you solve the problem "
  "of hunger in your world? Kill the Mutant Ivies to collect Mutant Saplings.",

  "Azman Orman mutant sarmaşıklarla dolu! Bu bitkiler çok hızlı büyür. Her yaprak, büyüdükten sonra sıradaki tur kendi başına büyüyebilir."
  " Ancak, her parça ancak 16 tur içinde bir kez büyüyebilir. Azman Orman dışındaki diyarlarda, Mutant Sarmaşık sadece altıgen hücrelerde büyüyebilir.\n\n"
  "Belki bu kadar hızlı büyüyen bitkiler dünyandaki açlık sorununu çözebilir? Mutant Fidanları toplamak için Mutant Sarmaşıkları öldür.")

S("Trees in this forest can be chopped down. Big trees take two turns to chop down.",
  "Bu ormandaki ağaçlar kesilebilir. Büyük ağaçların kesilmesi iki tur alır."
  )

/* ACHIEVEMENTS

		"NEW_ACHIEVEMENT_5_24_NAME"	"Mutant Fidan"
		"NEW_ACHIEVEMENT_5_24_DESC"	"Bir Mutant Fidan bul ve topla."
		"NEW_ACHIEVEMENT_5_25_NAME"	"Orman Trolü"
		"NEW_ACHIEVEMENT_5_25_DESC"	"10 Mutant Fidan topla."
		"NEW_ACHIEVEMENT_5_26_NAME"	"Mutant Sarmaşık"
		"NEW_ACHIEVEMENT_5_26_DESC"	"25 Mutant Fidan topla."
		"NEW_ACHIEVEMENT_5_27_NAME"	"Sarmaşık Efendisi"
		"NEW_ACHIEVEMENT_5_27_DESC"	"50 Mutant Fidan topla."
		"NEW_ACHIEVEMENT_5_28_NAME"	"Şimşek Çakması"
		"NEW_ACHIEVEMENT_5_28_DESC"	"Bir Fulgurit bul ve topla."
		"NEW_ACHIEVEMENT_5_29_NAME"	"Fırtına Trolü"
		"NEW_ACHIEVEMENT_5_29_DESC"	"10 Fulgurit topla."
		"NEW_ACHIEVEMENT_5_30_NAME"	"Metal Canavarı"
		"NEW_ACHIEVEMENT_5_30_DESC"	"25 Fulgurit topla."
		"NEW_ACHIEVEMENT_5_31_NAME"	"Zengin Metal Canavarı"
		"NEW_ACHIEVEMENT_5_31_DESC"	"50 Fulgurit topla."

*/


#undef Orb

S("TRANSLATIONWARNING",
  "ÇEVİRİ UYARISI: Türkçe çevirisi güncel değil -- 8.1'den sonra eklenen özellikleri")

S("TRANSLATIONWARNING2",
  "çevirmek isterseniz lütfen zeno@attnam.com adresinden benimle iletişime geçin.")

S("summon Bonfire", "Kampateşi çıkar")
S("Hyperstone Quest", "Aşkıntaş Görevi")
S("summon dead orbs", "ölü küre çıkar")
S("summon a Monster", "Bir canavar çıkar")
S("gain orb powers", "küre güçleri kazan")
S("summon a Golem", "Golem çıkar")
S("summon Thumpers", "Gümleyen çıkar")
S("summon Ivy", "Sarmaşık çıkar")
S("lose all treasure", "tüm hazineyi kaybet")
S("gain kills", "leşler kazan.")
S("Select the land ---", "Diyar seç ---")
S("summon Mimics", "Taklitçiler çıkar")
S("summon orbs", "küre çıkar")
S("deplete orb powers", "küre güçlerini tüket")
S("Safety (quick save)", "Güvenlik (hızlı kayıt)")
S("summon treasure", "hazine çıkar")
S("summon lots of treasure", "çok hazine çıkar")
S("--- and teleport there", "--- ve oraya ışınlan.")
S("summon Sand Worm", "Kumkurdu çıkar")
S("summon Orb of Yendor", "Yendorun Küresini çıkar")
S("rotate the character", "karakteri döndür")
